package com.gx.obe.server.common.agent;

import com.gx.obe.server.common.json.JsonUtil;
import com.gx.obe.server.common.vo.ProjectTypeVo;
import com.gx.obe.server.management.dictionary.entity.ProjectTemplate;
import com.gx.obe.server.management.dictionary.service.ProjectTemplateService;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.function.Function;
import java.util.function.Predicate;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * @author chenxw
 * @Description: 项目模板代理
 */
public class ProjectTemplateAgent {

    private Stream<ProjectTemplate> projectTemplateStream;

    private ProjectTemplateAgent(ProjectTemplateService PTS) {
        projectTemplateStream = Optional.of(PTS).map(ProjectTemplateService::getAllList).map(List::stream).orElse(null);
    }

    /**
     * @return
     * @Description: 初始化
     * @author chenxw
     */
    public static ProjectTemplateAgent init(ProjectTemplateService PTS) {
        return new ProjectTemplateAgent(PTS);
    }

    /**
     * @param function
     * @param predicate
     * @return
     * @Description: 添加过滤器
     * @author chenxw
     */
    public <T> ProjectTemplateAgent filterType(Function<ProjectTypeVo, T> function, Predicate<T> predicate) {
        return filterType(t -> predicate.test(function.apply(t)));
    }

    /**
     * @param predicate
     * @return
     * @Description: 添加过滤器
     * @author chenxw
     */
    public ProjectTemplateAgent filterType(Predicate<ProjectTypeVo> predicate) {
        return filter(t -> predicate.test(getProjectType(t.getProjectType())));
    }

    /**
     * @param function
     * @param predicate
     * @return
     * @Description: 添加过滤器
     * @author chenxw
     */
    public <T> ProjectTemplateAgent filter(Function<ProjectTemplate, T> function, Predicate<T> predicate) {
        return filter(t -> predicate.test(function.apply(t)));
    }

    /**
     * @param predicate
     * @return
     * @Description: 添加过滤器
     * @author chenxw
     */
    public ProjectTemplateAgent filter(Predicate<ProjectTemplate> predicate) {
        projectTemplateStream = Optional.ofNullable(projectTemplateStream).map(s -> s.filter(predicate)).orElse(null);
        return this;
    }

    /**
     * @return
     * @Description: 获取过滤后的数据
     * @author chenxw
     */
    public List<ProjectTemplate> get() {
        return Optional.ofNullable(projectTemplateStream).map(s -> s.collect(Collectors.toList())).orElseGet(ArrayList::new);
    }

    /**
     * @param projectType
     * @return
     * @Description: json转对象
     * @author chenxw
     */
    public static ProjectTypeVo getProjectType(String projectType) {
        return JsonUtil.strToObject(projectType, ProjectTypeVo.class);
    }

}
