package com.gx.obe.server.common.log;

import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.context.ApplicationEventPublisher;

import com.gx.obe.server.common.json.JsonUtil;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.evaluation.service.impl.BidPriceResultServiceImpl;
import com.gx.obe.server.management.log.entity.SysLog;

import lombok.AllArgsConstructor;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;

@Aspect
@AllArgsConstructor
public class LogAspect {
//	private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(LogAspect.class);

	private final ApplicationEventPublisher publisher;
 
	@SneakyThrows
	@Around("@annotation(sysLogAnnotation)")
	public Object around(ProceedingJoinPoint point,SysLogAnnotation sysLogAnnotation) {
//		String strClassName = point.getTarget().getClass().getName();
//		String strMethodName = point.getSignature().getName();
//		LOG.debug("[类名]:{},[方法]:{}", strClassName, strMethodName);
		SysLog logVo = LogUtils.getSysLog();
 		logVo.setLevel(sysLogAnnotation.level());
		logVo.setTitle(sysLogAnnotation.detail());
 		Long startTime = System.currentTimeMillis();
 		Object obj = null;
 		try {
 			obj = point.proceed();
		} catch (Exception e) {
			logVo.setException(e.toString());
 		}
		logVo.setReturnValue(StringUtils.toString(obj));
		Long endTime = System.currentTimeMillis();
		logVo.setTime(endTime - startTime);
		publisher.publishEvent(new LogEvent(logVo));
		return obj;
	}

 
}
