package com.gx.obe.server.common.utils;

import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class SortUtils {
	public static String defaultPattern = "##,###,###,###,##0.00##";
	private Map<String, String> sortResult = new HashMap<String, String>();
	private List<Double> sortList; 
	private boolean desc = true;

	public SortUtils (List<Double> sortList, boolean desc){
		this.sortList = sortList;
		this.desc = desc;
		getSortMap();
		
	}
	public SortUtils (List<Double> sortList){
		this(sortList, true);
	}
	
	public static String fmtNumber(Object v) {
		if (v == null){
			return "";
		}
		try {
			return(new DecimalFormat(defaultPattern).format(v)).toString();
		} catch (Exception e) {
			return "";
		}
	}

	public static String fmtNumber(Object v, String pattern) {
		if (v == null){
			return "";
		}
		try {
			return (new DecimalFormat(pattern).format(v)).toString();
		} catch (Exception e) {
			return "";
		}
	}

	public static double round(Object v) {
		if (v == null)
			return 0;
		BigDecimal b = new BigDecimal(v.toString());
		BigDecimal one = new BigDecimal("1");
		return b.divide(one, 2, BigDecimal.ROUND_HALF_UP).doubleValue();
	}

	public static double round(Object v, int scale) {
		if (v == null)
			return 0;
		if (scale < 0) {
			throw new IllegalArgumentException(
					"The scale must be a positive integer or zero");
		}
		BigDecimal b = new BigDecimal(v.toString());
		BigDecimal one = new BigDecimal("1");
		return b.divide(one, scale, BigDecimal.ROUND_HALF_UP).doubleValue();
	}

	public static int intRound(Object v) {
		if (v == null)
			return 0;
		BigDecimal b = new BigDecimal(v.toString());
		BigDecimal one = new BigDecimal("1");
		return (int) b.divide(one, 0, BigDecimal.ROUND_HALF_UP).doubleValue();
	}

	public static double myRound(double v) {
		String s1 = v + "";
		double returnval = 0;
		int index = s1.indexOf(".");
		if (index > 0) {
			s1 = s1.substring(0, index + 2);
			returnval = Double.parseDouble(s1);
		} else {
			returnval = v;
		}
		return returnval;
	}

	/** 
	 * @Description: 获得数值的排序map  
	 * @author guoyr
	 * @param desc 倒序排序  
	 * @return  
	 * @Exception   
	 */
	private void getSortMap(){
		if(null != sortList && sortList.size() > 0){
			sortResult.clear();
			Collections.sort(sortList,new SortComparator(desc));
			int sort = 1;
			for(double sortNum : sortList ){
				String sortKey = fmtNumber(sortNum);
				if(!sortResult.containsKey(sortKey)){
					sortResult.put(sortKey, (sort++)+"");
				}
			}
		}
	}
	
	public void addItem(Double sortItem){
		if(null == sortList){
			sortList = new ArrayList<Double>();
		}
		if(!sortList.contains(sortItem)){
			sortList.add(sortItem);
			getSortMap();
		}
	}
	public void removeItem(Double sortItem){
		if(null != sortList && sortList.size() > 0){
			sortList.remove(sortItem);	
			getSortMap();
		}
	}
	
	/** 
	 * @Description:  得到排序
	 * @author guoyr
	 * @param   
	 * @return  
	 * @Exception   
	 */
	public String getSort(Double sortValue){
		String sort = sortResult.get(fmtNumber(sortValue));
		return null == sort ? "" : sort;
	}
	
	/** 
	 * @Description:  得到排序
	 * @author guoyr
	 * @param   
	 * @return  
	 * @Exception   
	 */
	public int getSortNo(Double sortValue){
		String sort = sortResult.get(fmtNumber(sortValue));
		return (null != sort && !"".equals(sort))?Integer.parseInt(sort):0;
	}
	
	private  class SortComparator implements Comparator<Double> {
		boolean desc = true;
		public SortComparator(boolean desc){
			this.desc = desc;
		}
		public int compare(Double sortValue1, Double sortValue2) {
			if(sortValue1.compareTo(sortValue2) > 0){
				return (desc?-1:1)*1;
			}else if (sortValue1.compareTo(sortValue2) < 0){
				return (desc?-1:1)*(-1);
			}else {
				return 0;
			}
//			if(sortValue1 > sortValue2){
//				return (desc?-1:1)*1;
//			}else if (sortValue1 == sortValue2){
//				return 0;
//			}else {
//				return (desc?-1:1)*(-1);
//			}
		}
	}

}
