package com.gx.obe.server.common.utils;

import java.beans.Introspector;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Random;

/**
 * StringUtil utility.
 * @author guoyr
 */
public abstract class StringUtils {
	
	private static final String CHARS = "AcdeopqrsSTUVWCD4abXYZ01IJKLlm2B3fghijk678EFGHnt5MNOPQR9uvwxyz";
	
	private static final Random RANDOM = new Random();
	
	public static final String WHITESPACE = " \n\r\f\t";
	
	/**
	 * 字符串是否为<code>null</code>或为<code>""</code>
	 * @param input 输入
	 * @return true如果为空或null,否则false
	 */
	public static boolean isEmpty(String input) {
		return null == input || 0 == input.length();
	}
	
	public static boolean isNotEmpty(String input) {
		return null != input && input.length() > 0;
	}
	
	public static boolean hasLength(CharSequence str) {
		return (str != null && str.length() > 0);
	}
	
	public static String toString(Object obj) {
		if(null == obj) {
			return "";
		}
		return obj.toString();
	}
	
	
	
	public static boolean equals(String str1, String str2) {
		if (str1 == str2) {
			return true;
		}
		return str1 == null ? str2 == null : str1.equals(str2);
	}
	
	public static boolean hasLength(String str) {
		return hasLength((CharSequence) str);
	}
	
	public static boolean hasText(CharSequence str) {
		if (!hasLength(str)) {
			return false;
		}
		int strLen = str.length();
		for (int i = 0; i < strLen; i++) {
			if (!Character.isWhitespace(str.charAt(i))) {
				return true;
			}
		}
		return false;
	}
	
	public static boolean hasText(String str) {
		return hasText((CharSequence) str);
	}
	
	public static String capitalize(String str) {
		return changeFirstCharacterCase(str, true);
	}
	
	public static String decapitalize(String fieldName) {
		return Introspector.decapitalize(fieldName);
	}
	
	public static String changeFirstCharacterCase(String str, boolean capitalize) {
		if (str == null || str.length() == 0) {
			return str;
		}
		StringBuffer buf = new StringBuffer(str.length());
		if (capitalize) {
			buf.append(Character.toUpperCase(str.charAt(0)));
		} else {
			buf.append(Character.toLowerCase(str.charAt(0)));
		}
		buf.append(str.substring(1));
		try {
			return buf.toString();
		} finally {
			buf.setLength(0);
			buf = null;
		}
	}
	
	/**
	 * 产生固定长度的随机字符串
	 * @param length 长度
	 * @return 随机字符串
	 */
	public static String fixed(int length) {
		return random(length, CHARS);
	}
	
	/**
	 * 产生长度随机(不超过固定长度max,至少为1)的随机字符串
	 * @param max 最大长度
	 * @return 长度随机(不超过固定长度max)的随机字符串
	 */
	public static String random(int max) {
		return random(1, max);
	}
	
	/**
	 * 产生长度随机(不超过固定长度max,至少为min)的随机字符串
	 * @param min 最小长度
	 * @param max 最大长度
	 * @return 随机字符串
	 */
	public static String random(int min, int max) {
		int count = NumberUtils.random(min, max);
		return fixed(count);
	}
	
	public static String random(int count, String chars) {
		if (chars == null) {
			return random(count, 0, 0, false, false, null, RANDOM);
		}
		return random(count, 0, chars.length(), false, false, chars.toCharArray(), RANDOM);
	}
	
	public static String lowerCase(String str) {
		if (str == null) {
			return null;
		}
		return str.toLowerCase();
	}
	
	public static String upperCase(String str) {
		if (str == null) {
			return null;
		}
		return str.toUpperCase();
	}
	
	/**
	 * <p>
	 * Splits the provided text into an array, using whitespace as the separator. Whitespace is defined by {@link Character#isWhitespace(char)}.
	 * </p>
	 * <p>
	 * The separator is not included in the returned String array. Adjacent separators are treated as one separator. For more control over the split use the StrTokenizer class.
	 * </p>
	 * <p>
	 * A <code>null</code> input String returns <code>null</code>.
	 * </p>
	 * StringUtils.split(null) = null StringUtils.split("") = [] StringUtils.split("abc def") = ["abc", "def"] StringUtils.split("abc  def") = ["abc", "def"] StringUtils.split(" abc ") = ["abc"]
	 * @param str the String to parse, may be null
	 * @return an array of parsed StringUtil, <code>null</code> if null String input
	 */
	public static String[] split(String str) {
		return split(str, null, -1);
	}
	
	public static String substringBefore(String str, String separator) {
		if (isEmpty(str) || separator == null) {
			return str;
		}
		if (separator.length() == 0) {
			return "";
		}
		int pos = str.indexOf(separator);
		if (pos <= -1) {
			return str;
		}
		return str.substring(0, pos);
	}
	
	public static String substringAfter(String str, String separator) {
		if (isEmpty(str)) {
			return str;
		}
		if (separator == null) {
			return "";
		}
		int pos = str.indexOf(separator);
		if (pos <= -1) {
			return "";
		}
		return str.substring(pos + separator.length());
	}
	
	public static int count(String str, String sub) {
		if (str == null || sub == null || str.length() == 0 || sub.length() == 0) {
			return 0;
		}
		int count = 0, pos = 0, idx = 0;
		while ((idx = str.indexOf(sub, pos)) != -1) {
			++count;
			pos = idx + sub.length();
		}
		return count;
	}
	
	/**
	 * <p>
	 * Splits the provided text into an array, separator specified. This is an alternative to using StringTokenizer.
	 * </p>
	 * <p>
	 * The separator is not included in the returned String array. Adjacent separators are treated as one separator. For more control over the split use the StrTokenizer class.
	 * </p>
	 * <p>
	 * A <code>null</code> input String returns <code>null</code>.
	 * </p>
	 * StringUtils.split(null, *) = null StringUtils.split("", *) = [] StringUtils.split("a.b.c", '.') = ["a", "b", "c"] StringUtils.split("a..b.c", '.') = ["a", "b", "c"] StringUtils.split("a:b:c", '.') = ["a:b:c"] StringUtils.split("a b c", ' ') = ["a", "b", "c"]
	 * @param str the String to parse, may be null
	 * @param separatorChar the character used as the delimiter
	 * @return an array of parsed StringUtil, <code>null</code> if null String input
	 * @since 2.0
	 */
	public static String[] split(String str, char separatorChar) {
		return splitWorker(str, separatorChar, false);
	}
	
	/**
	 * <p>
	 * Splits the provided text into an array, separators specified. This is an alternative to using StringTokenizer.
	 * </p>
	 * <p>
	 * The separator is not included in the returned String array. Adjacent separators are treated as one separator. For more control over the split use the StrTokenizer class.
	 * </p>
	 * <p>
	 * A <code>null</code> input String returns <code>null</code>. A <code>null</code> separatorChars splits on whitespace.
	 * </p>
	 * StringUtils.split(null, *) = null StringUtils.split("", *) = [] StringUtils.split("abc def", null) = ["abc", "def"] StringUtils.split("abc def", " ") = ["abc", "def"] StringUtils.split("abc  def", " ") = ["abc", "def"] StringUtils.split("ab:cd:ef", ":") = ["ab", "cd", "ef"]
	 * @param str the String to parse, may be null
	 * @param separatorChars the characters used as the delimiters, <code>null</code> splits on whitespace
	 * @return an array of parsed StringUtil, <code>null</code> if null String input
	 */
	public static String[] split(String str, String separatorChars) {
		return splitWorker(str, separatorChars, -1, false);
	}
	
	/**
	 * <p>
	 * Splits the provided text into an array with a maximum length, separators specified.
	 * </p>
	 * <p>
	 * The separator is not included in the returned String array. Adjacent separators are treated as one separator.
	 * </p>
	 * <p>
	 * A <code>null</code> input String returns <code>null</code>. A <code>null</code> separatorChars splits on whitespace.
	 * </p>
	 * <p>
	 * If more than <code>max</code> delimited substrings are found, the last returned string includes all characters after the first <code>max - 1</code> returned strings (including separator characters).
	 * </p>
	 * StringUtils.split(null, *, *) = null StringUtils.split("", *, *) = [] StringUtils.split("ab de fg", null, 0) = ["ab", "cd", "ef"] StringUtils.split("ab   de fg", null, 0) = ["ab", "cd", "ef"] StringUtils.split("ab:cd:ef", ":", 0) = ["ab", "cd", "ef"] StringUtils.split("ab:cd:ef", ":", 2) = ["ab", "cd:ef"]
	 * @param str the String to parse, may be null
	 * @param separatorChars the characters used as the delimiters, <code>null</code> splits on whitespace
	 * @param max the maximum number of elements to include in the array. A zero or negative value implies no limit
	 * @return an array of parsed StringUtil, <code>null</code> if null String input
	 */
	public static String[] split(String str, String separatorChars, int max) {
		return splitWorker(str, separatorChars, max, false);
	}
	
	public static boolean startsWithIgnoreCase(String str, String prefix) {
		if (str == null || prefix == null) {
			return false;
		}
		if (str.startsWith(prefix)) {
			return true;
		}
		if (str.length() < prefix.length()) {
			return false;
		}
		String lcStr = str.substring(0, prefix.length()).toLowerCase();
		String lcPrefix = prefix.toLowerCase();
		return lcStr.equals(lcPrefix);
	}
	
	public static boolean endsWithIgnoreCase(String str, String suffix) {
		if (str == null || suffix == null) {
			return false;
		}
		if (str.endsWith(suffix)) {
			return true;
		}
		if (str.length() < suffix.length()) {
			return false;
		}
		
		String lcStr = str.substring(str.length() - suffix.length()).toLowerCase();
		String lcSuffix = suffix.toLowerCase();
		return lcStr.equals(lcSuffix);
	}
	
	public static boolean equalsIgnoreCase(String str1, String str2) {
		return str1 == null ? str2 == null : str1.equalsIgnoreCase(str2);
	}
	
	/**
	 * Performs the logic for the <code>split</code> and <code>splitPreserveAllTokens</code> methods that return a maximum array length.
	 * @param str the String to parse, may be <code>null</code>
	 * @param separatorChars the separate character
	 * @param max the maximum number of elements to include in the array. A zero or negative value implies no limit.
	 * @param preserveAllTokens if <code>true</code>, adjacent separators are treated as empty token separators; if <code>false</code>, adjacent separators are treated as one separator.
	 * @return an array of parsed StringUtil, <code>null</code> if null String input
	 */
	private static String[] splitWorker(String str, String separatorChars, int max, boolean preserveAllTokens) {
		// Performance tuned for 2.0 (JDK1.4)
		// Direct code is quicker than StringTokenizer.
		// Also, StringTokenizer uses isSpace() not isWhitespace()
		
		if (str == null) {
			return null;
		}
		int len = str.length();
		if (len == 0) {
			return new String[0];
		}
		List<String> list = new ArrayList<String>();
		int sizePlus1 = 1;
		int i = 0, start = 0;
		boolean match = false;
		boolean lastMatch = false;
		if (separatorChars == null) {
			// Null separator means use whitespace
			while (i < len) {
				if (Character.isWhitespace(str.charAt(i))) {
					if (match || preserveAllTokens) {
						lastMatch = true;
						if (sizePlus1++ == max) {
							i = len;
							lastMatch = false;
						}
						list.add(str.substring(start, i));
						match = false;
					}
					start = ++i;
					continue;
				}
				lastMatch = false;
				match = true;
				i++;
			}
		} else if (separatorChars.length() == 1) {
			// Optimise 1 character case
			char sep = separatorChars.charAt(0);
			while (i < len) {
				if (str.charAt(i) == sep) {
					if (match || preserveAllTokens) {
						lastMatch = true;
						if (sizePlus1++ == max) {
							i = len;
							lastMatch = false;
						}
						list.add(str.substring(start, i));
						match = false;
					}
					start = ++i;
					continue;
				}
				lastMatch = false;
				match = true;
				i++;
			}
		} else {
			// standard case
			while (i < len) {
				if (separatorChars.indexOf(str.charAt(i)) >= 0) {
					if (match || preserveAllTokens) {
						lastMatch = true;
						if (sizePlus1++ == max) {
							i = len;
							lastMatch = false;
						}
						list.add(str.substring(start, i));
						match = false;
					}
					start = ++i;
					continue;
				}
				lastMatch = false;
				match = true;
				i++;
			}
		}
		if (match || (preserveAllTokens && lastMatch)) {
			list.add(str.substring(start, i));
		}
		return (String[]) list.toArray(new String[list.size()]);
	}
	
	/**
	 * Performs the logic for the <code>split</code> and <code>splitPreserveAllTokens</code> methods that do not return a maximum array length.
	 * @param str the String to parse, may be <code>null</code>
	 * @param separatorChar the separate character
	 * @param preserveAllTokens if <code>true</code>, adjacent separators are treated as empty token separators; if <code>false</code>, adjacent separators are treated as one separator.
	 * @return an array of parsed StringUtil, <code>null</code> if null String input
	 */
	private static String[] splitWorker(String str, char separatorChar, boolean preserveAllTokens) {
		// Performance tuned for 2.0 (JDK1.4)
		
		if (str == null) {
			return null;
		}
		int len = str.length();
		if (len == 0) {
			return new String[0];
		}
		List<String> list = new ArrayList<String>();
		int i = 0, start = 0;
		boolean match = false;
		boolean lastMatch = false;
		while (i < len) {
			if (str.charAt(i) == separatorChar) {
				if (match || preserveAllTokens) {
					list.add(str.substring(start, i));
					match = false;
					lastMatch = true;
				}
				start = ++i;
				continue;
			}
			lastMatch = false;
			match = true;
			i++;
		}
		if (match || (preserveAllTokens && lastMatch)) {
			list.add(str.substring(start, i));
		}
		return (String[]) list.toArray(new String[list.size()]);
	}
	
	/**
	 * <p>
	 * Creates a random string based on a variety of options, using supplied source of randomness.
	 * </p>
	 * <p>
	 * If start and end are both <code>0</code>, start and end are set to <code>' '</code> and <code>'z'</code>, the ASCII printable characters, will be used, unless letters and numbers are both <code>false</code>, in which case, start and end are set to <code>0</code> and <code>Integer.MAX_VALUE</code>.
	 * <p>
	 * If set is not <code>null</code>, characters between start and end are chosen.
	 * </p>
	 * <p>
	 * This method accepts a user-supplied {@link Random} instance to use as a source of randomness. By seeding a single {@link Random} instance with a fixed seed and using it for each call, the same random sequence of strings can be generated repeatedly and predictably.
	 * </p>
	 * @param count the length of random string to create
	 * @param start the position in set of chars to start at
	 * @param end the position in set of chars to end before
	 * @param letters only allow letters?
	 * @param numbers only allow numbers?
	 * @param chars the set of chars to choose randoms from. If <code>null</code>, then it will use the set of all chars.
	 * @param random a source of randomness.
	 * @return the random string
	 * @throws ArrayIndexOutOfBoundsException if there are not <code>(end - start) + 1</code> characters in the set array.
	 * @throws IllegalArgumentException if <code>count</code> &lt; 0.
	 * @since 2.0
	 */
	private static String random(int count, int start, int end, boolean letters, boolean numbers, char[] chars, Random random) {
		if (count == 0) {
			return "";
		} else if (count < 0) {
			throw new IllegalArgumentException("Requested random string length " + count + " is less than 0.");
		}
		if ((start == 0) && (end == 0)) {
			end = 'z' + 1;
			start = ' ';
			if (!letters && !numbers) {
				start = 0;
				end = Integer.MAX_VALUE;
			}
		}
		
		char[] buffer = new char[count];
		int gap = end - start;
		
		while (count-- != 0) {
			char ch;
			if (chars == null) {
				ch = (char) (random.nextInt(gap) + start);
			} else {
				ch = chars[random.nextInt(gap) + start];
			}
			if ((letters && Character.isLetter(ch)) || (numbers && Character.isDigit(ch)) || (!letters && !numbers)) {
				if (ch >= 56320 && ch <= 57343) {
					if (count == 0) {
						count++;
					} else {
						// low surrogate, insert high surrogate after putting it in
						buffer[count] = ch;
						count--;
						buffer[count] = (char) (55296 + random.nextInt(128));
					}
				} else if (ch >= 55296 && ch <= 56191) {
					if (count == 0) {
						count++;
					} else {
						// high surrogate, insert low surrogate before putting it in
						buffer[count] = (char) (56320 + random.nextInt(128));
						count--;
						buffer[count] = ch;
					}
				} else if (ch >= 56192 && ch <= 56319) {
					// private high surrogate, no effing clue, so skip it
					count++;
				} else {
					buffer[count] = ch;
				}
			} else {
				count++;
			}
		}
		return new String(buffer);
	}

	private static String concat(String s1, String s2) {
		if (s2 == null) return s1;
		if (s1 == null) return s2;
		return s1.concat(s2);
	}

	public static String allConcat(String... str) {
		return Arrays.stream(str).reduce(StringUtils::concat).orElse(null);
	}

	public static void main(String[] args) {
		for (int i = 0; i < 20; i++) {
			System.out.println(fixed(8));
		}
		System.out.println("=========================");
		for (int i = 0; i < 20; i++) {
			System.out.println(random(10));
		}
		System.out.println("=========================");
		for (int i = 0; i < 20; i++) {
			System.out.println(random(3, 10));
		}
		System.out.println(capitalize("郭永荣"));
	}
}
