package com.gx.obe.server.config.token;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;

import com.auth0.jwt.JWT;
import com.auth0.jwt.JWTVerifier;
import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.exceptions.JWTDecodeException;
import com.auth0.jwt.exceptions.JWTVerificationException;
import com.gx.obe.server.common.utils.AESUtil;
import com.gx.obe.server.common.utils.IpUtil;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.config.token.util.TokenUtil;
import com.gx.obe.server.management.user.service.AuthUserService;

/**
 * @Description: token 拦截
 * @author mazc
 */
@Component
public class TokenInterceptor implements HandlerInterceptor {

	@Autowired
	public AuthUserService authUserService;

	@Override
	public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler)
			throws Exception {
		response.setCharacterEncoding("utf-8");
		String token = request.getHeader("ATUOKTHEN");
		if (token != null) {
			boolean result = verify(token, request);
			if (result) {
				return true;
			}
		}
		response.setContentType("application/json; charset=utf-8");
		try {
			response.sendError(401);
 		} catch (Exception e) {
			return false;
		}
		return false;
	}

	/**
	 * @Description: token 校验
	 * @author mazc
	 * @param token
	 * @param request
	 * @return
	 */
	private Boolean verify(String token, HttpServletRequest request) {
		try {
			JWTVerifier jwtVerifier = JWT.require(Algorithm.HMAC256(TokenUtil.TOKEN_SECRET)).withIssuer(TokenUtil.AUTH)
					.build();
//			String userId;
			String ip;
//			try {
////				userId = JWT.decode(token).getClaim(TokenUtil.USERID).asString();
//				ip = JWT.decode(token).getClaim(TokenUtil.IP).asString();
//			} catch (JWTDecodeException j) {
//				return false;
//			}
//			if (!StringUtils.equals(AESUtil.decrypt(ip), IpUtil.getIpAddr(request))) {
//				return false;
//			}
			// 暂时先不做这个判断，影响性能
//			AuthUserEntity user = authUserService.getById(AESUtil.decrypt(userId));
//			if (user == null) {
//				return false;
//			}
			jwtVerifier.verify(token);
		} catch (IllegalArgumentException | JWTVerificationException e) {
			return false;
		}
		return true;
	}

}
