package com.gx.obe.server.im.serverthread;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.math.BigDecimal;
import java.net.BindException;
import java.net.InetAddress;
import java.net.ServerSocket;
import java.net.Socket;
import java.util.Date;

import org.slf4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;

import com.gx.obe.server.common.enumeration.CommonEnum;
import com.gx.obe.server.im.ChatConstants;
import com.gx.obe.server.im.IMConstants;
import com.gx.obe.server.im.SendFileParam;
import com.gx.obe.server.im.enumeration.PropertieEnum;
import com.gx.obe.server.im.serverthread.SendFileThread.ServerSendFileListener;
import com.gx.obe.server.im.util.BeanContext;
import com.gx.obe.server.im.util.IMPropertiesUtil;
import com.gx.obe.server.management.im.entity.MessageFile;
import com.gx.obe.server.management.im.service.EmployeeService;
import com.gx.obe.server.management.im.service.MessageFileService;
/**<pre>
 * @Description:离线文件会发给服务器暂存，服务器接收完成以后，判断接收文件的客户端在线否，在线就立即通知他接收
 * 直到他拒绝或接收完成以后，才会删除数据库记录(此类只完成接收动作，完成以后会开启一个线程让在线者接收)
 * @Description:
 * @author guoyr
 * </pre>
 */
public class LixianWenJian implements ServerFileThread {
		private InetAddress sendIpAddress;
		private FileOutputStream fos = null;
		private BufferedOutputStream bos = null;
		private BufferedInputStream bis = null;
		private ServerSocket serverSocket = null; 
		private Socket sendSocket = null;
        private Logger LOG = org.slf4j.LoggerFactory.getLogger(LixianWenJian.class);
        private SendFilter sendFilter;
        private SendFileParam params;
        private File saveFile = null;
        private ServerSendFileListener serverSendFileListener;
        private long threadId = 0;
        private Thread thread;
         
        private MessageFileService messageFileService = BeanContext.getApplicationContext().getBean(MessageFileService.class);
		
		public LixianWenJian(SendFileParam params,InetAddress myIp, ServerSendFileListener serverSendFileListener, SendFilter sendFilter){
			this.params = params; 
			this.serverSendFileListener = serverSendFileListener; 
			this.sendIpAddress = myIp;
			this.sendFilter = sendFilter;
		}
		public void start(){
			thread = new Thread(this);
			thread.setName("服务器接收离线文件线程");
			thread.start();
			threadId = thread.getId();
		}
		public void run(){
			try {
				Thread.sleep(500);
//	        	fileName = jieShouLixian();// 发送端做为服务器进行发送文件
				
				// 服务器做为服务器进行接收文件
	        	if(saveOfflineFile()){
	        		
	        		//将离线文件写入数据库
	        		saveOfflineFileToDb(params.getFileName());
	        		
	        		// 然后检查接收者是否在线，如果在线就通知接收离线文件
	        		sendFilter.checkAndSendOfflineFile(params);
	        		
	        	};
                
			} catch (Exception ex) {
				LOG.error(ex.toString(),ex);
			}
		}
        private String createNewFile(String fileName){
            int x = 1;
            String newFileName = fileName.substring(0, fileName.lastIndexOf(".")) + "(" + x + ")"
                                    + fileName.substring(fileName.lastIndexOf("."));
            while( true ){
                File f = new File(System.getProperty("user.dir") + ChatConstants.UPFILE + newFileName);
                if ( !f.exists() )
                    break;
                x ++;
                newFileName = fileName.substring(0, fileName.lastIndexOf(".")) + "(" + x + ")"
                                    + fileName.substring(fileName.lastIndexOf("."));
            }
            return newFileName;
        }
        
        /**
         * @Description:  暂时先将离线文件保存在服务器
		 * @author guoyr
		 * @return
		 */
		private String jieShouLixian(){
			String fileName = params.getFileName();
			try {
				sendSocket = new Socket(sendIpAddress, params.getSendPort());
				bis = new BufferedInputStream(sendSocket.getInputStream());
				File f = new File(System.getProperty("user.dir") + ChatConstants.UPFILE + fileName);
				try{
	                if ( f.exists() ){
                        fileName = createNewFile(fileName);
                        f = new File(System.getProperty("user.dir") + ChatConstants.UPFILE + fileName);
                    }
	                if(!f.getParentFile().exists()){
	                	f.getParentFile().mkdirs();
	                }
                    f.createNewFile();
//                    file = f;
	                fos = new FileOutputStream(f);
	                bos = new BufferedOutputStream(fos); 
	                
	                byte[] bs = new byte[ChatConstants.MAX_LENGTH];
	                int len = bis.read(bs);
	                while( len != -1 ){
	                	bos.write(bs,0, len);
	                	bos.flush();
	                	len = bis.read(bs);
	                } 
	                
	            }catch(Exception ex){
	                LOG.error(ex.toString(),ex);
	            }
			} catch (Exception e) {
				LOG.error(e.toString(),e);
			}finally{
				stop();
			}
            return fileName;
		}
		
		
		
		/**
		 * @Description:  暂时先将离线文件保存在服务器
		 * @author guoyr
		 * @return
		 */
		private boolean saveOfflineFile(){
			int thisPort = -1;
			boolean saveOfflineFileSuccess = false;
			boolean createChangeServer = false;
			 while( !createChangeServer ){
		            try { 
		            	serverSocket = new ServerSocket(ChatConstants.SEND_FILE_PORT);
		            	serverSocket.setReceiveBufferSize(1024);
		                createChangeServer = true;
		            } catch (BindException e) {
		            	LOG.error(e.getMessage() + ChatConstants.SEND_FILE_PORT + "端口已被占用！");
		            	ChatConstants.SEND_FILE_PORT ++; continue;
		            } catch (IOException e) {
		            	LOG.error(e.getMessage() + ChatConstants.SEND_FILE_PORT + "端口已被占用！");
//		            	MessageDialog.openWarning(getShell(), "文件传输发生I/O异常。");
		            	stop();
		                return false;
		            } 
		        } 
			 	thisPort = ChatConstants.SEND_FILE_PORT ++ ;
		        if (ChatConstants.SEND_FILE_PORT > Integer.parseInt(IMPropertiesUtil.getProperty(PropertieEnum.FILE_RECEIVE_MAX_PORT, "7999"))){
		        	ChatConstants.SEND_FILE_PORT = Integer.parseInt(IMPropertiesUtil.getProperty(PropertieEnum.FILE_RECEIVE_PORT, "1981"));
		        };
		        
		        // 服务器建立好离线文件接收服务后，告诉发送方可以发送离线文件了
		        SendFileParam newParams = SendFileParam.copy(params);
		        newParams.setOrder(IMConstants.TELL_TO_BEGIN_SEND_FILE);
		        newParams.setReceiveId(params.getSendId());
		        newParams.setSendId(params.getReceiveId());
		        newParams.setSendPort(thisPort);
		        sendFilter.sendOfflineFileBegin(newParams);
		        try {
					// 等待对方连接到文件发送服务器
					sendSocket = serverSocket.accept();
					
					saveFile = getOfflineFile(params.getFileName());
					params.setFileName(saveFile.getName());
					fos = new FileOutputStream(saveFile);
					bos = new BufferedOutputStream(fos);
					
					bis = new BufferedInputStream(sendSocket.getInputStream());
					byte[] bs = new byte[ChatConstants.MAX_LENGTH];
					int len = bis.read(bs);
					long count = 0;
					while( len != -1 ){
						count += len;
						bos.write(bs,0, len);
						bos.flush();
						len = bis.read(bs);
					}
					saveOfflineFileSuccess = (count==params.getFileSize());
				} catch (FileNotFoundException e1) {
					LOG.error(e1.getMessage());
				} catch (IOException e1) {
					LOG.error(e1.getMessage());
				} finally{
					stop();
				}
			return saveOfflineFileSuccess;
		}
		
		
		private File getOfflineFile(String fileName){
			File f = new File(System.getProperty("user.dir") + ChatConstants.UPFILE + fileName);
			if ( f.exists() ){
				fileName = createNewFile(fileName);
				f = new File(System.getProperty("user.dir") + ChatConstants.UPFILE + fileName);
			}
			if(!f.getParentFile().exists()){
				f.getParentFile().mkdirs();
			}
			try {
				f.createNewFile();
			} catch (IOException e) {
				LOG.error(e.getMessage());
			}
			return f;
		}
		//OperatorUtil.SEND_OFFLINE_FILE + FG + myId + FG + clientId + FG + fileBytes + FG + fileName + FG + port;
		
		
		/**
		 * @Description:  写离线文件到数据库
		 * @author guoyr
		 * @param lixianFile
		 * @return
		 */
		private void saveOfflineFileToDb(String fileName){

        	if(null != fileName && !"".equals(fileName)){
        		MessageFile lixianFile = new MessageFile();
        		lixianFile.setSendTime(new Date());
        		lixianFile.setFileName(fileName);
        		lixianFile.setFileSize(new BigDecimal(params.getFileSize()));
        		lixianFile.setSendId(params.getSendId());
        		lixianFile.setReadType(CommonEnum.NO);
        		lixianFile.setReceiveId(params.getReceiveId());
        		messageFileService.saveOrUpdate(lixianFile);
        	}
		}
		
		public void stop(){
			thread = null;
			serverSendFileListener.removeServerFileThread(this);
			
			if (null != bis){
				try {
					bis.close();
				} catch (IOException e) {
				}
				bis = null;
			}
			if (null != bos){
				try {
					bos.close();
				} catch (IOException e) {
				}
				bos = null;
			} 
				
			if (null != fos){
				try {
					fos.close();
				} catch (IOException e) {
				}
				fos = null;
			} 
			if (null != sendSocket){
				try {
					sendSocket.close();
				} catch (IOException e) {
				}
				sendSocket = null;
			}
			if (null != serverSocket){
				try {
					serverSocket.close();
				} catch (IOException e) {
				}
				serverSocket = null;
			}
		}
		
		public boolean equals(Object obj) {
			return super.equals(obj);
		}

		public interface SendFilter{
			public void checkAndSendOfflineFile(SendFileParam params);
			public void sendOfflineFileBegin(SendFileParam params);
		}
		public long getThreadId() {
			return threadId;
		}
		public void deleteFile() {
			if(null != saveFile && saveFile.exists()){
				try {
					if(!saveFile.delete()){
						saveFile.deleteOnExit();
					}
				} catch (Exception e) {
				}
			}
		}
		public boolean isStop() {
			return null == thread;
		}
	}
