package com.gx.obe.server.management.config.controller;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gx.obe.server.common.base.BaseController;
import com.gx.obe.server.management.config.entity.SysConfig;
import com.gx.obe.server.management.config.entity.SysConfigValue;
import com.gx.obe.server.management.config.service.SysConfigService;
import com.gx.obe.server.management.vo.UpdateAssignPropertyVo;

import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;
/** 
 * @Description: 
 * @author mazc 
 */
@Api(tags = "")
@RestController
@AllArgsConstructor
@RequestMapping("/sysConfig")
public class ConfigController extends BaseController<SysConfigService,SysConfig>{
	@Autowired
	public SysConfigService sysConfigService;
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param sysConfigList 
	 */
	@PostMapping("/insertByBatch")
	public int insertByBatch(@RequestBody List<SysConfig> sysConfigList) {
		return sysConfigService.insertByBatch(sysConfigList);
	}
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param SysConfigList 
	 */
	@PostMapping("/updateByBatch")
	public int updateByBatch(@RequestBody List<SysConfig> SysConfigList) {
		return sysConfigService.updateByBatch(SysConfigList);
	}

	/**
	 * @Description: 指定字段修改
	 * @param vo
	 * @return
	 */
	@PostMapping("/updateAssignProperty")
	public boolean  updateAssignProperty(@RequestBody UpdateAssignPropertyVo<SysConfig> vo) {
		return sysConfigService.updateAssignProperty(vo.getEntity(), vo.getAttributes());
	}
	
	/**
	 * @Description: 验证配置名称唯一性
	 * @author mazc
	 * @param id
	 * @param configName
	 * @return boolean true：是唯一；false:不是唯一
	 */
	@GetMapping("/isUniqueConfigName")
	public boolean isUniqueConfigName(String id, String configName){
		return sysConfigService.isUniqueConfigName(id, configName);
	}
	
	/**
	 * @Description: 验证配置编码唯一性
	 * @author mazc
	 * @param id
	 * @param configCode
	 * @return
	 */
	@GetMapping("/isUniqueConfigCode")
	public boolean isUniqueConfigCode(String id, String configCode){
		return sysConfigService.isUniqueConfigCode(id, configCode);
	}
	
	/**
	 * @Description: 根据编码，获得数据配置对象。
	 * @author mazc
	 * @param configCode
	 * @return
	 */
	@GetMapping("/getConfigByCode")
	public SysConfig getConfigByCode(String configCode){
		return sysConfigService.getConfigByCode(configCode);
	}
	
	/**
	 * @Description: 根据配置编码，获得有效配置值集合。
	 * @author mazc
	 * @param configCode 配置编码
	 * @return List<ConfigValue>
	 */
	@GetMapping("/getConfigValueList")
	public List<SysConfigValue> getConfigValueList(String configCode){
		return sysConfigService.getConfigValueList(configCode);
	}
}