package com.gx.obe.server.management.dictionary.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.management.dictionary.dao.DecEnvelopeMapper;
import com.gx.obe.server.management.dictionary.dao.EncEnvelopeMapper;
import com.gx.obe.server.management.dictionary.entity.EncEnvelope;
import com.gx.obe.server.management.dictionary.service.EncEnvelopeService;

/** 
 * @Description: 
 * @author mazc 
 */
@Service
@Transactional
public class EncEnvelopeServiceImpl extends ServiceImpl<EncEnvelopeMapper, EncEnvelope> implements EncEnvelopeService {

	@Autowired
	private EncEnvelopeMapper encEnvelopeMapper;
	
	@Autowired
	private DecEnvelopeMapper decEnvelopeMapper;
	
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeEncEnvelopeList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch (List<EncEnvelope> ObeEncEnvelopeList){
		return encEnvelopeMapper.updateBatchList(ObeEncEnvelopeList);
	}
	
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeEncEnvelopeList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer insertByBatch (List<EncEnvelope> ObeEncEnvelopeList){
		return encEnvelopeMapper.insertByBatch(ObeEncEnvelopeList);
	}

	/** 
	 * @Description: 上传投标信封
	 * @author mazc
	 * @param encEnvelope
	 * @return 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean uploadEncEnvelope(EncEnvelope encEnvelope) {
		encEnvelopeMapper.deleteSupplierEnvelop(encEnvelope.getTenderId(), encEnvelope.getSupplierId());
		decEnvelopeMapper.deleteSupplierEnvelop(encEnvelope.getTenderId(), encEnvelope.getSupplierId());
		return encEnvelopeMapper.insert(encEnvelope) > 0 ;
	}

	/** 
	 * @Description: 删除项目的投标信封信息
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean deleteTenderEnvelop(String tenderId) {
		int count = 0;
		count += encEnvelopeMapper.deleteTenderEnvelop(tenderId);
		count += decEnvelopeMapper.deleteTenderEnvelop(tenderId);
		return count > 0;
	}

	/** 
	 * @Description: 删除供应商的投标信封信息
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @return 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean deleteSupplierEnvelop(String tenderId, String supplierId) {
		int count = 0;
		count += encEnvelopeMapper.deleteSupplierEnvelop(tenderId,supplierId);
		count += decEnvelopeMapper.deleteSupplierEnvelop(tenderId,supplierId);
		return count > 0;
	}

	@Override
	public boolean deleteByTenderIdAndSupplierId(String tenderId, String supplierId) {
		QueryWrapper<EncEnvelope> wrapper = new QueryWrapper<EncEnvelope>();
		wrapper.lambda().eq(EncEnvelope::getTenderId, tenderId).eq(EncEnvelope::getSupplierId, supplierId);
		return encEnvelopeMapper.delete(wrapper) > 0;
	}
	

}
