package com.gx.obe.server.management.evaluation.controller;
import com.gx.obe.server.common.base.BaseController;
import com.gx.obe.server.common.vo.RequestBodyEntity;
import com.gx.obe.server.management.evaluation.entity.BidPriceHisResult;
import com.gx.obe.server.management.evaluation.service.BidPriceHisResultService;
import com.gx.obe.server.management.price.service.BidPriceRoundStatusService;
import com.gx.obe.server.management.price.service.ReBidPriceRoundService;
import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;
 
/** 
 * @Description: 
 * @author mazc 
 */
@Api(tags = "历史投标报价")
@RestController
@AllArgsConstructor
@RequestMapping("/bidPriceHisResult")
public class BidPriceHisResultController extends BaseController<BidPriceHisResultService,BidPriceHisResult>{
	@Autowired
	public BidPriceHisResultService bidPriceHisResultServices;
	
	@Autowired
	public BidPriceRoundStatusService bidPriceRoundStatusService;
	
	@Autowired
	public ReBidPriceRoundService reBidPriceRoundService;
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeBidPriceHisResultList 
	 */
	@PostMapping("/insertByBatch")
	public int insertByBatch(@RequestBody List<BidPriceHisResult> ObeBidPriceHisResultList) {
		return bidPriceHisResultServices.insertByBatch(ObeBidPriceHisResultList);
	}
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeBidPriceHisResultList 
	 */
	@PostMapping("/updateByBatch")
	public int updateByBatch(@RequestBody List<BidPriceHisResult> ObeBidPriceHisResultList) {
		return bidPriceHisResultServices.updateByBatch(ObeBidPriceHisResultList);
	}
	
	/**
	 * @Description: 通过tenderId删除
	 * @author mazc
	 * @param tenderID
	 * @return 
	 */
	@GetMapping("/deleteBidPrcieByTenderId")
	public int deleteBidPrcieByTenderId(String tenderId) {
		return bidPriceHisResultServices.deleteBidPrcieByTenderId(tenderId);
	}
	
	
	/**
	 * @Description: 获得供应商报价的最大轮次集合
	 * @author mazc
	 * @param supplierList
	 * @return 
	 */
//	@PostMapping("/getSupplierMaxPriceRoundMap")
//	public Map<String,Integer> getSupplierMaxPriceRoundMap(@RequestBody RequestBodyEntity<Supplier> request){
//		List<Supplier> supplierList = request.getEntityList();
//		String tenderId = (String) request.getParam("tenderId");
//		return bidPriceHisResultServices.getSupplierMaxPriceRoundMap(tenderId, supplierList);
//	}
	@GetMapping("/getSupplierMaxPriceRoundMap")
	public Map<String,Integer> getSupplierMaxPriceRoundMap(String tenderId, String supplierId){
		return bidPriceHisResultServices.getSupplierMaxPriceRoundMap(tenderId, supplierId);
	}
	
	
	/**
	 * @Description: 获得项目下指定轮次报价供应商报价完成情况
	 * @author guoyr
	 * @param tenderId
	 * @param round
	 * @param supplierId
	 * @return 
	 */
	@GetMapping("/getSupplierBidPriceRoundComplateStatus")
	public Map<String, Boolean> getSupplierBidPriceRoundComplateStatus(String tenderId, String supplierId, int round){
		return bidPriceHisResultServices.getSupplierBidPriceRoundComplateStatus(tenderId, supplierId, round);
	}
	
	/**
	 * @Description: 获得供应商的报价结果
	 * @author mazc
	 * @param tenderId
	 * @param bidprcieId
	 * @param supplierId
	 * @return 
	 */
	@GetMapping("/getBidPriceHisResultList")
	public List<BidPriceHisResult> getBidPriceHisResultList(String tenderId, String bidPriceId,String supplierId){
		return bidPriceHisResultServices.getBidPriceHisResultList(tenderId, bidPriceId, supplierId);
	}
	
	/**
	 * @Description: 按轮次获得历史报价结果
	 * @author mazc
	 * @param tenderId
	 * @param bidPriceId
	 * @param round
	 * @return 
	 */
	@GetMapping("/getBidPriceHisResultListByRound")
	public List<BidPriceHisResult> getBidPriceHisResultListByRound(String tenderId, String bidPriceId ,int round){
		return bidPriceHisResultServices.getBidPriceHisResultListByRound(tenderId, bidPriceId, round);
	}
	
	/**
	 * @Description: 获得供应商的历史报价
	 * @author guoyr
	 * @param tenderId
	 * @param supplierId
	 * @param round
	 * @return 
	 */
	@GetMapping("/getSupplierBidPriceHisResultListByRound")
	public List<BidPriceHisResult> getSupplierBidPriceHisResultListByRound(String tenderId, String supplierId ,int round){
		return bidPriceHisResultServices.getSupplierBidPriceHisResultListByRound(tenderId, supplierId, round);
	}
	
	/**
	 * @Description: 通过TenderId、SupplierId、bidPriceRound 查询报价
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @param bidPriceRound
	 * @return 
	 */
	@GetMapping("/getBidPriceHisResultByTenderId")
	public BidPriceHisResult getBidPriceHisResultByTenderId(String tenderId,String supplierId,int bidPriceRound){
		return bidPriceHisResultServices.getBidPriceHisResultByTenderId(tenderId, supplierId, bidPriceRound);
	}
	
	/**
	 * @Description: 通过bidPriceId、SupplierId、bidPriceRound 查询报价
	 * @author mazc
	 * @param supplierId
	 * @param bidPriceId
	 * @param bidPriceRound
	 * @return 
	 */
	@GetMapping("/getHisResultPriceIdAndSupplierIdAndPriceRound")
	public BidPriceHisResult getHisResultPriceIdAndSupplierIdAndPriceRound(String supplierId ,String bidPriceId ,int bidPriceRound){
		return bidPriceHisResultServices.getHisResultPriceIdAndSupplierIdAndPriceRound(supplierId, bidPriceId, bidPriceRound);
	}
	
	/**
	 * @Description: 
	 * @author mazc
	 * @return 
	 */
	@GetMapping("/getBidPriceHisResultBySupplierId")
	public List<BidPriceHisResult> getBidPriceHisResultBySupplierId(String supplierId ,int bidPriceRound){
		return bidPriceHisResultServices.getBidPriceHisResultBySupplierId(supplierId, bidPriceRound);
	}
	
	/**
	 * @Description: 通过TenderId查询历史报价集合
	 * @author mazc
	 * @param supplierId
	 * @param bidPriceRound
	 * @return 
	 */
	@GetMapping("/getBidPriceHisResultByTenderIdList")
	public List<BidPriceHisResult> getBidPriceHisResultByTenderIdList(String tenderId ,String bidPriceId){
		return bidPriceHisResultServices.getBidPriceHisResultByTenderIdList(tenderId, bidPriceId);
	}
	
	/**
	 * @Description: 保存修改
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @param bidPriceId
	 * @param bidPriceHisResult
	 * @return 
	 */
	@PostMapping("/saveSupplierHisBidPriceResult")
	@Deprecated 
	public boolean saveSupplierHisBidPriceResulta(@RequestBody RequestBodyEntity<BidPriceHisResult> request) {
		BidPriceHisResult bidPriceHisResult = request.getEntity();
		String tenderId = (String) request.getParam("tenderId");
		String supplierId = (String) request.getParam("supplierId");
		String bidPriceId = (String) request.getParam("bidPriceId");
		return bidPriceHisResultServices.saveSupplierHisBidPriceResulta(tenderId, supplierId, bidPriceId, bidPriceHisResult);
	}


	/**
	 * @Description: 保存供应商多轮报价
	 * @param tenderId
	 * @param supplierId
	 * @param bidPriceResultList
	 * @return
	 */
	@PostMapping("/saveSupplierReBidPriceHisResult")
	public boolean saveSupplierReBidPriceHisResult(@RequestBody RequestBodyEntity<BidPriceHisResult> requestBodyEntity) {
		String tenderId = (String)requestBodyEntity.getParam("tenderId");
		String supplierId = (String)requestBodyEntity.getParam("supplierId");
		String roundId = (String)requestBodyEntity.getParam("roundId");
		String downUrl = (String)requestBodyEntity.getParam("downUrl");
		String fileName = (String)requestBodyEntity.getParam("fileName");
		List<BidPriceHisResult> bidPriceHisResultList = requestBodyEntity.getEntityList();
		return bidPriceHisResultServices.saveSupplierReBidPriceHisResultAndBidPriceFile(tenderId, supplierId, roundId, bidPriceHisResultList, downUrl, fileName);
	}

	/**
	 * @Description: 保存供应商多轮报价
 	 * @param tenderId
	 * @param supplierId
	 * @param bidPriceResultList
	 * @return
	 */
	@PostMapping("/saveUpateSupplierReBidPriceHisResult")
	public boolean saveUpateSupplierReBidPriceHisResult(@RequestBody RequestBodyEntity<BidPriceHisResult> requestBodyEntity) {
		String tenderId = (String)requestBodyEntity.getParam("tenderId");
		String supplierId = (String)requestBodyEntity.getParam("supplierId");
		String roundId = (String)requestBodyEntity.getParam("roundId");
		List<BidPriceHisResult> bidPriceHisResultList = requestBodyEntity.getEntityList();
		return bidPriceHisResultServices.saveUpateSupplierReBidPriceHisResult(tenderId, supplierId, roundId, bidPriceHisResultList);
	}
	
}