package com.gx.obe.server.management.evaluation.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.gx.obe.server.common.log.OperationType;
import com.gx.obe.server.common.log.SysLogAnnotation;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.common.vo.RequestBodyEntity;
import com.gx.obe.server.management.evaluation.entity.EvaluationFactor;
import com.gx.obe.server.management.evaluation.entity.EvaluationStep;
import com.gx.obe.server.management.evaluation.service.EvaluationFactorService;
import com.gx.obe.server.management.project.entity.TenderProject;
import com.gx.obe.server.management.vo.BatchUpdatePropertyVo;
import com.gx.obe.server.management.vo.ImportEvaluationFactorVo;
import com.gx.obe.server.management.vo.SaveBusinessFactorVo;
import com.gx.obe.server.management.vo.UpdateAssignPropertyVo;
import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;

/**
 * 
 * @author
 * @Title: EvaluationFactorController
 * @Package com.gx.obe.server.management.evaluation.controller
 * @Description:
 * @author: XiaoMa Pro - myzhichao@163.com
 * @date: 2019-05-17
 * @version V1.0
 * @Copyright: 2019 www.msypro.com Inc. All rights reserved.
 * 
 */
@Api(tags = "评估管理")
@RestController
@AllArgsConstructor
@RequestMapping("/evaluationFactor")
public class EvaluationFactorController {
    
    @Autowired
    public EvaluationFactorService evaluationFactorService;
    
    /**
     * @Description: 根据项目id获取指标数量
     * @author chenxw
     * @param tenderId
     * @return 
     */
    @GetMapping("/getFactorCountByTenderId")
    public int getFactorCountByTenderId(String tenderId) {
        return evaluationFactorService.getFactorCountByTenderId(tenderId);
    }
    
    @PostMapping("/updateAssignProperty")
    @SysLogAnnotation(detail="指定字段修改指标信息",level = 0,operationType = OperationType.UPDATE)
	public boolean updateAssignProperty(@RequestBody UpdateAssignPropertyVo<EvaluationFactor> updateAssignPropertyVo) {
    	EvaluationFactor evaluationFactor = updateAssignPropertyVo.getEntity();
         String[] attributes = updateAssignPropertyVo.getAttributes();
         return evaluationFactorService.updateAssignProperty(evaluationFactor, attributes);
 	}
    
    /**
     * @Description: 根据项目id获取指标列表
     * @author chenxw
     * @param tenderId
     * @return 
     */
    @GetMapping("/getFactorListByTenderId")
    public List<EvaluationFactor> getFactorListByTenderId(String tenderId) {
        return evaluationFactorService.getFactorListByTenderId(tenderId);
    }
    
    /**
     * @Description: 通过TenderId删除
     * @author mazc
     * @param tenderId
     */
    @GetMapping("/deleteById")
    @SysLogAnnotation(detail="按项目删除所有指标",level = 0,operationType = OperationType.DELETE)
    public void deleteById(String id) {
        evaluationFactorService.removeById(id);
    }
    
    /**
     * @Description: 批量更新
     * @author mazc
     * @param evaluationFactorList
     * @return
     */
    @PostMapping("/updateList")
    public boolean updateList(@RequestBody List<EvaluationFactor> evaluationFactorList) {
        return evaluationFactorService.updateBatchById(evaluationFactorList);
    }
    
    
	@PostMapping("/batchUpdateProperty")
    public boolean batchUpdateProperty(@RequestBody BatchUpdatePropertyVo<EvaluationFactor> batchUpdatePropertyVo) {
        List<EvaluationFactor> evaluationFactorList = batchUpdatePropertyVo.getEntityList();
        String[] attributes = batchUpdatePropertyVo.getAttributes();
        return evaluationFactorService.batchUpdateProperty(evaluationFactorList, attributes) > 0;
    }
    
    
    /**
     * @Description: 批量更新
     * @author mazc
     * @param evaluationFactorList
     * @return
     */
    @PostMapping("/batchSave")
    public boolean batchSave(@RequestBody List<EvaluationFactor> evaluationFactorList) {
        return evaluationFactorService.saveBatch(evaluationFactorList);
    }
    
    /**
     * @Description:
     * @author mazc
     * @param factorId
     * @param tenderId
     * @param evalBidType
     * @return
     */
    @GetMapping("/existCreditFactor")
    public boolean existCreditFactor(String factorId, String tenderId, String evalBidType) {
        QueryWrapper<EvaluationFactor> wrapper = new QueryWrapper<EvaluationFactor>();
        wrapper.select("FACTOR_ID").lambda().eq(EvaluationFactor::getTenderId, tenderId).eq(EvaluationFactor::getEvalBidType, evalBidType);
        if (StringUtils.isNotEmpty(factorId)) {
            wrapper.lambda().ne(EvaluationFactor::getId, factorId);
        }
        return evaluationFactorService.list(wrapper).size() > 0;
    }
    
    /**
     * @Description: 根据id修改
     * @author mazc
     * @param evaluationFactor
     * @return
     */
    @PostMapping("/updateFactor")
    @SysLogAnnotation(detail="修改指标信息",level = 0,operationType = OperationType.UPDATE)
    public boolean updateTenderProjecInfo(@RequestBody EvaluationFactor evaluationFactor) {
        UpdateWrapper<EvaluationFactor> updateWrapper = new UpdateWrapper<EvaluationFactor>();
        updateWrapper.lambda().eq(EvaluationFactor::getId, evaluationFactor.getId());
        return evaluationFactorService.update(evaluationFactor, updateWrapper);
    }
    
    @GetMapping("/getById")
    public EvaluationFactor findById(String id) {
        return evaluationFactorService.getById(id);
    }
    
    @GetMapping("/findTenderAndParentId")
    public List<EvaluationFactor> findCondition(String tenderId, String parentId, String[] auditType) {
    	QueryWrapper<EvaluationFactor> wrapper = new QueryWrapper<EvaluationFactor>();
    	wrapper.lambda().select(EvaluationFactor::getId, EvaluationFactor::getFactorName, EvaluationFactor::getFactorScore, EvaluationFactor::getFactorWeight, 
    			EvaluationFactor::getEvalBidType,EvaluationFactor::getAuditType,EvaluationFactor::getFactorCode)
    	
        .eq(EvaluationFactor::getTenderId, tenderId);
        if(null != parentId) {
        	wrapper.lambda().eq(EvaluationFactor::getParentId, parentId);
        }else {
        	wrapper.lambda().isNull(EvaluationFactor::getParentId);
        }
        if (auditType != null && auditType.length > 0) {
            wrapper.in(EvaluationFactor.AUDIT_TYPE, (Object[]) auditType);
        }
        return evaluationFactorService.list(wrapper);
    }
    
    @GetMapping("/findItemizedPriceSize")
    public Integer findItemizedPriceSize(String tenderId, String auditType, String id) {
        QueryWrapper<EvaluationFactor> QueryWrapper = new QueryWrapper<EvaluationFactor>();
        QueryWrapper.select(EvaluationFactor.FACTOR_ID).lambda().eq(EvaluationFactor::getTenderId, tenderId).eq(EvaluationFactor::getAuditType, auditType).isNotNull(EvaluationFactor::getBidPriceCode);
        if (id != null) {
            QueryWrapper.lambda().ne(EvaluationFactor::getId, id);
        }
        return evaluationFactorService.count(QueryWrapper);
    }
    
    @GetMapping("/findBatchIdsList")
    public List<EvaluationFactor> findBatchIds(List<String> idList) {
        return evaluationFactorService.selectBatchIds(idList);
    }
    
    /**
     * @Description: 保存或修改符合性评审指标
     * @author guoyr
     * @param factor
     * @return
     */
    @PostMapping("/saveOrUpdateComplianceEvaluationFactor")
    @SysLogAnnotation(detail="保存或修改符合性评审指标",level = 0,operationType = OperationType.UPDATE)
    public EvaluationFactor saveOrUpdateComplianceEvaluationFactor(@RequestBody EvaluationFactor factor) {
        return evaluationFactorService.saveOrUpdateComplianceEvaluationFactor(factor);
    }
    
    /**
     * @Description: 保存或修改打分评审指标
     * @author mazc
     * @param factor 实体类
     * @param changeWeigth 是否修改权重
     * @return
     */
    @PostMapping("/saveEvaluationFactor")
    @SysLogAnnotation(detail="保存或修改打分评审指标",level = 0,operationType = OperationType.UPDATE)
    public EvaluationFactor saveEvaluationFactor(@RequestBody RequestBodyEntity<EvaluationFactor> requestBodyEntity) {
        return evaluationFactorService.saveEvaluationFactor(requestBodyEntity.getEntity(), (boolean) requestBodyEntity.getParam("changeWeigth"));
    }
    
    /**
     * @Description: 删除指标
     * @author chenxw
     * @param factor
     * @return
     */
    @PostMapping("/deleteEvaluationFactor")
    @SysLogAnnotation(detail="删除指标",level = 0,operationType = OperationType.DELETE)
    public int deleteEvaluationFactor(@RequestBody EvaluationFactor factor) {
        return evaluationFactorService.deleteEvaluationFactor(factor);
    }
    
    /**
     * @Description: 获得价格指标
     * @author guoyr
     * @param tenderId
     * @return
     */
    @GetMapping("/getPriceEvaluationFactor")
    public EvaluationFactor getPriceEvaluationFactor(String tenderId) {
        return evaluationFactorService.getPriceEvaluationFactor(tenderId);
    }
    
    /**
     * @Description: 交换两个指标的排序
     * @author guoyr
     * @param source
     * @param target
     */
    @GetMapping("/changeEvaluationFactorSortNo")
    public void changeEvaluationFactorSortNo(String sourceId, String targetId) {
        evaluationFactorService.changeEvaluationFactorSortNo(sourceId, targetId);
    }
    
    /**
     * @Description: 获得指标的最大序号
     * @author mazc
     * @param tenderId
     * @param auditType
     * @param parentId
     * @return
     */
    @GetMapping("/getMaxEvaluationFactorSortNo")
    public int getMaxEvaluationFactorSortNo(String tenderId, String auditType, String parentId) {
        return evaluationFactorService.getMaxEvaluationFactorSortNo(tenderId, auditType, parentId);
    }
    
    /**
     * @Description: 获得指标的数量
     * @author mazc
     * @param tenderId
     * @param auditType
     * @param parentId
     * @return
     */
    @GetMapping("/getEvaluationFactorCount")
    public int getEvaluationFactorCount(String tenderId, String auditType) {
    	return evaluationFactorService.getEvaluationFactorCount(tenderId, auditType);
    }
    
    /**
     * @Description: 通过Tenderid 查询所有
     * @author mazc
     * @param tenderId
     * @param auditType
     * @return
     */
    @GetMapping("/getAllEvaluationFactorList")
    public List<EvaluationFactor> getAllEvaluationFactorList(String tenderId, String auditType) {
        return evaluationFactorService.getAllEvaluationFactorList(tenderId, auditType);
    }
    
    /**
     * @Description: 导入投标报价指标
     * @author mazc
     * @param tenderId
     * @param parentFactor
     * @return
     */
    @PostMapping("/importBidPriceFactor")
    @SysLogAnnotation(detail="导入投标报价指标",level = 0,operationType = OperationType.INSERT)
    public Integer importBidPriceFactor(@RequestBody RequestBodyEntity<EvaluationFactor> requestBodyEntity) {
        return evaluationFactorService.importBidPriceFactor((String) requestBodyEntity.getParam("tenderId"), requestBodyEntity.getEntity());
    }
    
    /**
     * @Description: 导入指标
     * @author guoyr
     * @param tenderId
     * @param complianceFactorList 符合性指标
     * @param detailFactorList 打分指标
     * @param priceFactorList 价格指标
     * @return
     */
    @PostMapping("/importEvaluationFactor")
    @SysLogAnnotation(detail="导入指标",level = 0,operationType = OperationType.INSERT)
    public boolean importEvaluationFactor(@RequestBody ImportEvaluationFactorVo importEvaluationFactorVo) {
        String tenderId = importEvaluationFactorVo.getTenderId();
        List<EvaluationFactor> complianceFactorList = importEvaluationFactorVo.getComplianceFactorList();
        List<EvaluationFactor> detailFactorList = importEvaluationFactorVo.getDetailFactorList();
        List<EvaluationFactor> priceFactorList = importEvaluationFactorVo.getPriceFactorList();
        List<EvaluationFactor> billFactorList = importEvaluationFactorVo.getBillFactorList();
        return evaluationFactorService.importEvaluationFactor(tenderId, complianceFactorList, detailFactorList, priceFactorList, billFactorList);
    }
    
    /**
     * @Description: 通过TenderId删除所有
     * @author mazc
     * @param tenderId
     */
    @GetMapping("/delAllEvaluationFactor")
    @SysLogAnnotation(detail="删除项目下所有指标",level = 0,operationType = OperationType.DELETE)
    public void delAllEvaluationFactor(String tenderId) {
        evaluationFactorService.delAllEvaluationFactor(tenderId);
    }
    
    /**
     * @Description: 按分类删除指标
     * @author chenxw
     * @param tenderId
     * @param auditType
     * @return
     */
    @GetMapping("/delEvaluationFactorByType")
    @SysLogAnnotation(detail="按分类删除指标",level = 0,operationType = OperationType.DELETE)
    public int delEvaluationFactorByType(String tenderId, String auditType) {
        return evaluationFactorService.delEvaluationFactorByType(tenderId, auditType);
    }
    
    /**
     * @Description: 获得可为评标步骤分配置的指标
     * @author guoyr
     * @param tenderId
     * @param auditType
     * @return
     */
    @GetMapping("/getFactorListOfEvaluationStep")
    public List<EvaluationFactor> getFactorListOfEvaluationStep(String tenderId, String auditType, String stepId) {
        return evaluationFactorService.getFactorListOfEvaluationStep(tenderId, auditType, stepId);
    }
    
    /**
     * @Description: 获得指定评标步骤的评审指标树
     * @author guoyr
     * @param tenderId
     * @param stepId
     * @return
     */
    @PostMapping("/getEvaluationStepFactorTreeList")
    public List<EvaluationFactor> getEvaluationStepFactorTreeList(@RequestBody RequestBodyEntity<EvaluationStep> requestBodyEntity) {
        String tenderId = (String) requestBodyEntity.getParam("tenderId");
        EvaluationStep evaluationStep = requestBodyEntity.getEntity();
        return evaluationFactorService.getEvaluationStepFactorTreeList(tenderId, evaluationStep);
    }
    
    /**
     * @Description: 获得专家在指定评标步骤的评审指标树
     * @author guoyr
     * @param tenderId
     * @param stepId
     * @param userId
     * @return
     */
    @PostMapping("/getExpertEvaluationStepFactorTreeList")
    public List<EvaluationFactor> getExpertEvaluationStepFactorTreeList(@RequestBody RequestBodyEntity<EvaluationStep> requestBodyEntity) {
        String tenderId = (String) requestBodyEntity.getParam("tenderId");
        EvaluationStep evaluationStep = requestBodyEntity.getEntity();
        String userId = (String) requestBodyEntity.getParam("userId");
        return evaluationFactorService.getExpertEvaluationStepFactorTreeList(tenderId, evaluationStep, userId);
    }
    
    /**
     * @Description: 获取项目下指定类型的指标ids
     * @author mazc
     * @param tenderId
     * @param auditType
     * @return
     */
    @GetMapping("/getFactorIdList")
    public List<Object> getFactorIdList(String tenderId, String auditType) {
        return evaluationFactorService.getFactorIdList(tenderId, auditType);
    }
    
    /**
     * @Description: 保存下载的评审指标
     * @author guoyr
     * @param tenderId
     * @param evaluationFactorList
     * @return
     */
    @PostMapping("/saveDownloadEvaluationFactor")
    @SysLogAnnotation(detail="保存下载的评审指标",level = 0,operationType = OperationType.INSERT)
    public int saveDownloadEvaluationFactor(@RequestBody RequestBodyEntity<EvaluationFactor> requestBodyEntity) {
        String tenderId = (String) requestBodyEntity.getParam("tenderId");
        List<EvaluationFactor> evaluationFactorList = requestBodyEntity.getEntityList();
        return evaluationFactorService.saveDownloadEvaluationFactor(tenderId, evaluationFactorList);
    }
    
    /**
     * @Description: 获得指定评标步骤的评审指标(未对指标信息封装树节点，现在主要用于生成报表使用)
     * @author guoyr
     * @param tenderId
     * @param evaluationStep
     * @param removeTopOnly 当顶级指标只有一个时，取掉顶级指标
     * @return
     */
    @PostMapping("/getEvaluationStepFactorList")
    public List<EvaluationFactor> getEvaluationStepFactorList(@RequestBody RequestBodyEntity<EvaluationStep> requestBodyEntity) {
        String tenderId = (String) requestBodyEntity.getParam("tenderId");
        EvaluationStep evaluationStep = requestBodyEntity.getEntity();
        boolean removeTopOnly = (boolean) requestBodyEntity.getParam("removeTopOnly");
        return evaluationFactorService.getEvaluationStepFactorList(tenderId, evaluationStep, removeTopOnly);
    }
    
    /**
     * @Description: 获得专家在指定评标步骤的评审指标(未对指标信息封装树节点，现在主要用于生成报表使用)
     * @author guoyr
     * @param tenderId
     * @param evaluationStep
     * @param removeTopOnly 当顶级指标只有一个时，取掉顶级指标
     * @return
     */
    @PostMapping("/getExpertEvaluationStepFactorList")
    public List<EvaluationFactor> getExpertEvaluationStepFactorList(@RequestBody RequestBodyEntity<EvaluationStep> requestBodyEntity) {
        String tenderId = (String) requestBodyEntity.getParam("tenderId");
        EvaluationStep evaluationStep = requestBodyEntity.getEntity();
        String userId = (String) requestBodyEntity.getParam("userId");
        boolean removeTopOnly = (boolean) requestBodyEntity.getParam("removeTopOnly");
        return evaluationFactorService.getExpertEvaluationStepFactorList(tenderId, evaluationStep, userId, removeTopOnly);
    }
    
    /**
     * @Description: 获得父级评审指标分值
     * @param tenderId
     * @param stepId
     * @return
     */
    @GetMapping("/getParentFactorScore")
    public BigDecimal getParentFactorScore(String tenderId, String stepId) {
        return evaluationFactorService.getParentFactorScore(tenderId, stepId);
    }
    
    /**
     * @Description: 获得指定专家对投标人的评标结果
     * @author guoyr
     * @param tenderId
     * @param userId
     * @param supplierId
     * @param stepId
     * @param auditType
     * @return
     */
    @GetMapping("/getEvaluationFactorResultList")
    public List<EvaluationFactor> getEvaluationFactorResultList(String tenderId, String userId, String supplierId, String stepId, String auditType) {
        return evaluationFactorService.getEvaluationFactorResultList(tenderId, userId, supplierId, stepId, auditType);
    }
    
    /**
     * @Description: 验证是否已经存在投标总报价价格指标
     * @author chenxw
     * @param tenderId
     * @param factorId
     * @return
     */
    @GetMapping("/hasTotalBidPriceFactor")
    public boolean hasTotalBidPriceFactor(String tenderId, String factorId) {
        return evaluationFactorService.hasTotalBidPriceFactor(tenderId, factorId);
    }
    
    /**
     * @Description: 获得指定指标类形的权重
     * @author guoyr
     * @param tenderId
     * @param auditType
     * @return
     */
    @GetMapping("/getWeightByAuditType")
    public BigDecimal getWeightByAuditType(String tenderId, String auditType) {
		return evaluationFactorService.getWeightByAuditType(tenderId, auditType);
    }
    
    /**
     * @Description: 根据清单类型获取清单指标
     * @author chenxw
     * @param tenderId
     * @param billType
     * @return
     */
    @GetMapping("/getBillFactoryByType")
    public EvaluationFactor getBillFactoryByType(String tenderId, String billType) {
        return evaluationFactorService.getBillFactoryByType(tenderId, billType);
    }

    /**
     * @Description: 根据指标编号获取指标
     * @author chenxw
     * @param tenderId
     * @param factorCode
     * @return 
     */
    @GetMapping("/getFactorByFactorCode")
    public EvaluationFactor getFactorByFactorCode(String tenderId, String factorCode) {
        return evaluationFactorService.getFactorByFactorCode(tenderId, factorCode);
    }

    /**
     * @Description: 保存商务指标
     * @author chenxw
     * @param saveBusinessFactorVo
     * @return
     */
    @PostMapping("/saveBusinessFactor")
    @SysLogAnnotation(detail="保存商务指标",level = 0,operationType = OperationType.INSERT)
    public boolean saveBusinessFactor(@RequestBody SaveBusinessFactorVo saveBusinessFactorVo) {
        TenderProject tenderProject = saveBusinessFactorVo.getTenderProject();
        EvaluationFactor businessFactor = saveBusinessFactorVo.getBusinessFactor();
        return evaluationFactorService.saveBusinessFactor(tenderProject, businessFactor);
    }

}