package com.gx.obe.server.management.evaluation.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.entity.ReflecUtils;
import com.gx.obe.server.common.enumeration.BidPriceEnum;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.NowTimeUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.evaluation.dao.BidPriceHisResultMapper;
import com.gx.obe.server.management.evaluation.dao.BidPriceResultMapper;
import com.gx.obe.server.management.evaluation.entity.BidPriceHisResult;
import com.gx.obe.server.management.evaluation.entity.BidPriceResult;
import com.gx.obe.server.management.evaluation.service.BidPriceHisResultService;
import com.gx.obe.server.management.evaluation.service.BidPriceResultService;
import com.gx.obe.server.management.price.dao.BidPriceRoundStatusMapper;
import com.gx.obe.server.management.price.dao.ReBidPriceRoundMapper;
import com.gx.obe.server.management.price.entity.BidPriceRoundStatus;
import com.gx.obe.server.management.price.entity.ReBidPriceRound;
import com.gx.obe.server.management.price.service.BidPriceRoundStatusService;
import com.gx.obe.server.management.price.service.ReBidPriceRoundService;
import com.gx.obe.server.management.supplier.dao.SupplierOpeningResultMapper;
import com.gx.obe.server.management.supplier.service.SupplierOpeningResultService;
 /** 
 * @Description: 
 * @author mazc 
 */
@Service
@Transactional
public class BidPriceHisResultServiceImpl extends ServiceImpl<BidPriceHisResultMapper, BidPriceHisResult> implements BidPriceHisResultService {

	@Autowired
	private BidPriceHisResultMapper bidPriceHisResultMapper;
	@Autowired
	private BidPriceResultMapper bidPriceResultMapper;
	@Autowired
	private BidPriceResultService bidPriceResultService;
	@Autowired
	private ReBidPriceRoundMapper reBidPriceRoundMapper;
	
	@Autowired
	private SupplierOpeningResultMapper supplierOpeningResultMapper;
	
	@Autowired
	private SupplierOpeningResultService supplierOpeningResultService;
	
	@Autowired
	private BidPriceRoundStatusMapper bidPriceRoundStatusMapper;
	
	@Autowired
	private BidPriceRoundStatusService bidPriceRoundStatusService;
	
	@Autowired
	private ReBidPriceRoundService reBidPriceRoundService;
 	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeBidPriceHisResultList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch (List<BidPriceHisResult> ObeBidPriceHisResultList){
		return bidPriceHisResultMapper.updateBatchList(ObeBidPriceHisResultList);
	}
	
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeBidPriceHisResultList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer insertByBatch (List<BidPriceHisResult> ObeBidPriceHisResultList){
		return bidPriceHisResultMapper.insertByBatch(ObeBidPriceHisResultList);
	}

	/** 
	 * @Description: 通过tenderid 删除
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	@Override
	public Integer deleteBidPrcieByTenderId(String tenderId) {
		
		//查询该项目所以供应商的第一轮历史报价
		QueryWrapper<BidPriceHisResult> queryWrapperOldPrice = new QueryWrapper<BidPriceHisResult>();
		queryWrapperOldPrice.lambda().eq(BidPriceHisResult::getTenderId, tenderId).eq(BidPriceHisResult::getBidPriceRound, 1);
	
		//查询出来当前项目所有供应商的历史报价暂存使用
		List<BidPriceHisResult> bidPriceHisResultList = bidPriceHisResultMapper.selectList(queryWrapperOldPrice);
						
		//查询当前项目所有报价结果 
		QueryWrapper<BidPriceResult> queryWrapperOldPriceResul = new QueryWrapper<BidPriceResult>();
		queryWrapperOldPriceResul.lambda().eq(BidPriceResult::getTenderId, tenderId);
		
		//查询出来当前项目所有供应商的报价
		List<BidPriceResult> oldBidPriceResultList =bidPriceResultMapper.selectList(queryWrapperOldPriceResul);
		
		//还原项目报价至第一轮历史报价
		List<BidPriceResult> updateBidPriceResultList = new ArrayList<BidPriceResult>();
		List<BidPriceResult> insertBidPriceResultList = new ArrayList<BidPriceResult>();
		
		//前项目所有报价结果map
		Map<String, BidPriceResult> bidPriceResultMap = new HashMap<String, BidPriceResult>();
		oldBidPriceResultList.forEach(bidPriceResult -> {
			String key = bidPriceResult.getSupplierId() + bidPriceResult.getBidPriceId();
			bidPriceResultMap.put(key, bidPriceResult);
		});
		
		bidPriceHisResultList.forEach(bidPriceHisResult -> {
			String supplierId = bidPriceHisResult.getSupplierId();
			String key = supplierId + bidPriceHisResult.getBidPriceId();
			BidPriceResult bidPriceHisResultTemp = bidPriceResultMap.get(key);	
			if(null == bidPriceHisResultTemp) {
				bidPriceHisResultTemp = new BidPriceResult();
			}
			bidPriceHisResultTemp.setBidPriceId(bidPriceHisResult.getBidPriceId());
			bidPriceHisResultTemp.setBidPrice(bidPriceHisResult.getBidPrice());
			bidPriceHisResultTemp.setFinalBidPrice(bidPriceHisResult.getFinalBidPrice());
			bidPriceHisResultTemp.setEvaluationPrice(bidPriceHisResult.getEvaluationPrice());
			bidPriceHisResultTemp.setPriceContent(bidPriceHisResult.getPriceContent());
			bidPriceHisResultTemp.setCurrencyCode(bidPriceHisResult.getCurrencyCode());
			bidPriceHisResultTemp.setCurrencyName(bidPriceHisResult.getCurrencyName());
			bidPriceHisResultTemp.setPriceUnit(bidPriceHisResult.getPriceUnit());
			bidPriceHisResultTemp.setFinalBidPrice(bidPriceHisResult.getFinalBidPrice());
			bidPriceHisResultTemp.setModifyReason(bidPriceHisResult.getModifyReason());
			bidPriceHisResultTemp.setCreateTime(bidPriceHisResult.getCreateTime());
			bidPriceHisResultTemp.setBidPriceName(bidPriceHisResult.getBidPriceName());
			if(StringUtils.isEmpty(bidPriceHisResultTemp.getId())) {
				bidPriceHisResultTemp.setId(IDUtils.getId());
				bidPriceHisResultTemp.setTenderId(tenderId);
				bidPriceHisResultTemp.setSupplierId(supplierId);
				insertBidPriceResultList.add(bidPriceHisResultTemp);
			}else{
				updateBidPriceResultList.add(bidPriceHisResultTemp);
			}
		});

		if(insertBidPriceResultList.size() > 0) {
			bidPriceResultMapper.insertByBatch(insertBidPriceResultList);			
		}
		
		if(updateBidPriceResultList.size() > 0) {
			bidPriceResultMapper.updateBatchList(updateBidPriceResultList);				
		}
		
		// 删除轮次表中的数据
		QueryWrapper<ReBidPriceRound> deleteQueryRoundWrapper = new QueryWrapper<ReBidPriceRound>();
		deleteQueryRoundWrapper.lambda().eq(ReBidPriceRound::getTenderId, tenderId);
		reBidPriceRoundMapper.delete(deleteQueryRoundWrapper);
		//计算供应商的总价
		supplierOpeningResultService.updateSupplierSumPrice(tenderId, null, true, true);
		
		//删除 历史表中所有的报价信息
		QueryWrapper<BidPriceHisResult> deleteQueryWrapper = new QueryWrapper<BidPriceHisResult>();
		deleteQueryWrapper.lambda().eq(BidPriceHisResult::getTenderId, tenderId);
 		return bidPriceHisResultMapper.delete(deleteQueryWrapper);
	}

	/** 
	 * @Description: 获得供应商报价的最大轮次集合
	 * @author mazc
	 * @param tenderId
	 * @param supplierList
	 * @return 
	 */
//	@Override
//	public Map<String, Integer> getSupplierMaxPriceRoundMap(String tenderId, List<Supplier> supplierList) {
//		Map<String,Integer>  supplierMaxPriceRoundMap = new HashMap<String, Integer>();
//		for(Supplier supplier : supplierList) {
//			Integer maxCount = bidPriceHisResultMapper.getSupplierMaxPriceRound(tenderId,supplier.getId(), null);
//			int iMax = null != maxCount ? maxCount : 0;
//			supplierMaxPriceRoundMap.put(supplier.getId(), iMax);
//		}
//		 
//		return supplierMaxPriceRoundMap;
//	}
	public Map<String, Integer> getSupplierMaxPriceRoundMap(String tenderId, String supplierId) {
		Map<String,Integer>  supplierMaxPriceRoundMap = new HashMap<String, Integer>();
		List<Map<String, Object>> supplierMaxRoundMapList = bidPriceHisResultMapper.getSupplierMaxPriceRound(tenderId, supplierId);
		if(null != supplierMaxRoundMapList) {
			for(Map<String, Object> supplierMaxRoundMap : supplierMaxRoundMapList) {
				Integer maxCount = (Integer)supplierMaxRoundMap.get("MAX_ROUND");
				if(null == maxCount || maxCount < 1) {
					maxCount = 1;
//				}else {
					// 历史报表表中只存历史报价记录，最新的报价在开标一览表中
//					maxCount += 1;
				}
				supplierMaxPriceRoundMap.put((String)supplierMaxRoundMap.get("SUPPLIER_ID"), maxCount);
			}
		}
		
		return supplierMaxPriceRoundMap;
	}
	
	/**
	 * @Description: 获得项目下指定轮次报价供应商报价完成情况
	 * @author guoyr
	 * @param tenderId
	 * @param round
	 * @param supplierId
	 * @return 
	 */
	public Map<String, Boolean> getSupplierBidPriceRoundComplateStatus(@Param("tenderId")String tenderId, @Param("supplierId")String supplierId, @Param("round")int round){
		Map<String,Boolean>  resultMap = new HashMap<String, Boolean>();
		List<Map<String, Object>> supplierMaxRoundMapList = bidPriceHisResultMapper.getSupplierBidPriceRoundComplateStatus(tenderId, supplierId, round);
		if(null != supplierMaxRoundMapList) {
			for(Map<String, Object> supplierMaxRoundMap : supplierMaxRoundMapList) {
				resultMap.put((String)supplierMaxRoundMap.get("SUPPLIER_ID"), null != supplierMaxRoundMap.get("CREATE_TIME"));
			}
		}
		
		return resultMap;
	}

	/** 
	 * @Description: 获得供应商的报价结果
	 * @author mazc
	 * @param tenderId
	 * @param bidprcieId
	 * @param supplierId
	 * @return 
	 */
	@Override
	public List<BidPriceHisResult> getBidPriceHisResultList(String tenderId, String bidPriceId, String supplierId) {
 		return bidPriceHisResultMapper.getBidPriceHisResultList(tenderId, bidPriceId, supplierId);
	}

	/** 
	 * @Description: 按轮次获得历史报价结果
	 * @author mazc
	 * @param tenderId
	 * @param bidPriceId
	 * @param round
	 * @return 
	 */
	@Override
	public List<BidPriceHisResult> getBidPriceHisResultListByRound(String tenderId, String bidPriceId, int round) {
		return bidPriceHisResultMapper.getBidPriceHisResultListByRound(tenderId, bidPriceId, round);
	}

	
	/**
	 * @Description: 获得供应商的历史报价
	 * @author guoyr
	 * @param tenderId
	 * @param supplierId
	 * @param round
	 * @return 
	 */
	public List<BidPriceHisResult> getSupplierBidPriceHisResultListByRound(String tenderId, String supplierId ,int round){
		return bidPriceHisResultMapper.getSupplierBidPriceHisResultListByRound(tenderId, supplierId, round);
	}
	/** 
	 * @Description:  通过TenderId、SupplierId、bidPriceRound 查询报价
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @param bidPriceRound
	 * @return 
	 */
	@Override
	public BidPriceHisResult getBidPriceHisResultByTenderId(String tenderId, String supplierId, int bidPriceRound) {
		QueryWrapper<BidPriceHisResult> queryWrapper = new QueryWrapper<BidPriceHisResult>();
		queryWrapper.lambda().eq(BidPriceHisResult::getTenderId, tenderId).eq(BidPriceHisResult::getSupplierId, supplierId)
		.eq(BidPriceHisResult::getBidPriceRound, bidPriceRound);
		return bidPriceHisResultMapper.selectOne(queryWrapper);
	}

	/** 
	 * @Description: 根据供应商id查询历史报价
	 * @author mazc
	 * @param supplierId
	 * @param bidPriceRound
	 * @return 
	 */
	@Override
	public List<BidPriceHisResult> getBidPriceHisResultBySupplierId(String supplierId, int bidPriceRound) {
		QueryWrapper<BidPriceHisResult> queryWrapper = new QueryWrapper<BidPriceHisResult>();
		queryWrapper.lambda().eq(BidPriceHisResult::getSupplierId, supplierId).eq(BidPriceHisResult::getBidPriceRound, bidPriceRound);
		return bidPriceHisResultMapper.selectList(queryWrapper);
	}

	/** 
	 * @Description: 通过TenderId查询历史报价集合
	 * @author mazc
	 * @param tenderId
	 * @param bidPriceId
	 * @return 
	 */
	@Override
	public List<BidPriceHisResult> getBidPriceHisResultByTenderIdList(String tenderId, String bidPriceId) {
		QueryWrapper<BidPriceHisResult> queryWrapper = new QueryWrapper<BidPriceHisResult>();
		queryWrapper.lambda().eq(BidPriceHisResult::getTenderId, tenderId).eq(BidPriceHisResult::getBidPriceId, bidPriceId);
		return bidPriceHisResultMapper.selectList(queryWrapper);
	}


	/** 
	 * @Description:  根据id更新指定字段
	 * @author mazc
	 * @param bidPriceHisResult
	 * @param strs
	 * @return 
	 */
	@Override
	public boolean updateAssignProperty(BidPriceHisResult bidPriceHisResult, String[] strs) {
		BidPriceHisResult evaluationStepTemp = ReflecUtils.reflex(bidPriceHisResult, strs,BidPriceHisResult.class);
		return bidPriceHisResultMapper.updateById(evaluationStepTemp) > 0;
		
	}
	/** 
	 * @Description: 保存历史报价
	 * @author mazc
	 * @param tenderId
	 * @param supplierId
	 * @param bidPriceId
	 * @param bidPriceHisResult
	 * @return 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean saveSupplierHisBidPriceResulta(String tenderId, String supplierId, String bidPriceId,
			BidPriceHisResult bidPriceHisResult) {
		boolean flag = true;
		boolean isLastPrice = false;
		int supplierMaxRound = bidPriceHisResultMapper.getSupplierMaxPriceRound(tenderId, supplierId, bidPriceId);
		if(null == bidPriceHisResult.getId()){
			bidPriceHisResult.setId(IDUtils.getId());
			flag = bidPriceHisResultMapper.insert(bidPriceHisResult) > 0;
			if(bidPriceHisResult.getBidPriceRound() >= supplierMaxRound -1){
				isLastPrice = true;
			}
		}else {
			flag = updateAssignProperty(bidPriceHisResult, new String[] {"id", "finalBidPrice", "evaluationPrice", "roundName","bidPriceMemo"});
			if(bidPriceHisResult.getBidPriceRound() >= supplierMaxRound){
				isLastPrice = true;
			}
		}
		
		if(isLastPrice){
			List<BidPriceResult> bidPriceResultList= bidPriceResultMapper.getSupplierBidPriceResultList(tenderId, bidPriceHisResult.getSupplierId()) ;
			if(null != bidPriceResultList && bidPriceResultList.size() > 0){
				BidPriceResult firstBidPriceResult = bidPriceResultList.get(0);
				firstBidPriceResult.setBidPrice(bidPriceHisResult.getBidPrice());
				firstBidPriceResult.setFinalBidPrice(bidPriceHisResult.getFinalBidPrice());
				firstBidPriceResult.setEvaluationPrice(bidPriceHisResult.getEvaluationPrice());
				firstBidPriceResult.setEvaluationPriceOriginal(null);
				bidPriceResultService.updateAssignProperty(firstBidPriceResult, new String[] {"id", "finalBidPrice", "evaluationPrice", "evaluationPriceOriginal"});
				supplierOpeningResultMapper.updateSupplierSumPrice(tenderId, supplierId, false, true);
			}else {
				// 目前多项报价不支持进行多轮报价
				supplierOpeningResultMapper.updateEvaluationPriceAndEvaluationPriceOriginal(bidPriceHisResult.getBidPrice(), null, tenderId, supplierId);
			}
		}
		return flag;
	}

	@Override
	public BidPriceHisResult getHisResultPriceIdAndSupplierIdAndPriceRound(String supplierId, String bidPriceId,
			int bidPriceRound) {
		QueryWrapper<BidPriceHisResult> queryWrapper = new QueryWrapper<BidPriceHisResult>();
		queryWrapper.lambda().eq(BidPriceHisResult::getBidPriceId, bidPriceId).eq(BidPriceHisResult::getSupplierId, supplierId)
		.eq(BidPriceHisResult::getBidPriceRound, bidPriceRound);
		return bidPriceHisResultMapper.selectOne(queryWrapper);
 	}

	/** 
	 * @Description: 获得指定项目报价轮次的历史报价
	 * @author mazc
	 * @param tenderId
	 * @param bidPriceRound
	 * @return 
	 */
	@Override
	public List<BidPriceHisResult> getBidPriceHisResultByTenderId(String tenderId, int bidPriceRound) {
		QueryWrapper<BidPriceHisResult> queryWrapper = new QueryWrapper<BidPriceHisResult>();
		queryWrapper.lambda().eq(BidPriceHisResult::getTenderId, tenderId)
		.eq(BidPriceHisResult::getBidPriceRound, bidPriceRound);
		return bidPriceHisResultMapper.selectList(queryWrapper);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean saveSupplierReBidPriceHisResult(String tenderId, String supplierId,String roundId,List<BidPriceHisResult> bidPriceHisResultList) {
	    if (bidPriceRoundStatusService.isCompletePriceBySupplier(roundId, supplierId)) {
	        return true;
        }
		Date openingTime = NowTimeUtils.getNowDate();
		if(null != bidPriceHisResultList && bidPriceHisResultList.size() > 0){
			for(BidPriceHisResult bidPriceResult : bidPriceHisResultList){
				if(null == bidPriceResult.getCreateTime()) {
					bidPriceResult.setCreateTime(openingTime);
				}
				bidPriceResult.setFinalBidPrice(bidPriceResult.getBidPrice());
			}
			bidPriceHisResultMapper.insertByBatch(bidPriceHisResultList);
			if(StringUtils.isNotEmpty(roundId)) {
				bidPriceRoundStatusMapper.updateCompletePriceStatusBySupplierId(roundId, supplierId,BidPriceEnum.PRICE_STATUS_OK) ;
			}
			supplierOpeningResultService.updateSupplierSumPrice(tenderId, supplierId, true, true);
			return true;
		}
		return false;
	}

	 @Override
	 @Transactional(rollbackFor = Exception.class)
	 public boolean saveSupplierReBidPriceHisResultAndBidPriceFile(String tenderId, String supplierId, String roundId, List<BidPriceHisResult> bidPriceHisResultList, String downUrl, String fileName) {
		 if (saveSupplierReBidPriceHisResult(tenderId, supplierId, roundId, bidPriceHisResultList)) {
			 if (downUrl == null || fileName == null) return true;
			 QueryWrapper<BidPriceRoundStatus> queryWrapper = new QueryWrapper<>();
			 queryWrapper.lambda()
					 .eq(BidPriceRoundStatus::getPriceRoundId, roundId)
					 .eq(BidPriceRoundStatus::getSupplierId, supplierId);
			 BidPriceRoundStatus bidPriceRoundStatus = bidPriceRoundStatusMapper.selectOne(queryWrapper);
			 bidPriceRoundStatus.setBidPriceFileUrl(downUrl);
			 bidPriceRoundStatus.setBidPriceFileName(fileName);
			 return bidPriceRoundStatusMapper.updateAssignProperty(bidPriceRoundStatus, new String[]{"bidPriceFileUrl", "bidPriceFileName"}) > 0;
		 }
		 return false;
	 }

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean saveUpateSupplierReBidPriceHisResult(String tenderId, String supplierId, String roundId,List<BidPriceHisResult> bidPriceHisResultList) {
		Date openingTime = NowTimeUtils.getNowDate();
		if(null != bidPriceHisResultList && bidPriceHisResultList.size() > 0){
			for(BidPriceHisResult bidPriceResult : bidPriceHisResultList){
				if(null == bidPriceResult.getCreateTime()) {
					bidPriceResult.setCreateTime(openingTime);
				}
			}
			bidPriceHisResultMapper.updateBatchList(bidPriceHisResultList);
			if(StringUtils.isNotEmpty(roundId)) {
				bidPriceRoundStatusMapper.updateCompletePriceStatusBySupplierId(roundId, supplierId,BidPriceEnum.PRICE_STATUS_OK) ;
				List<BidPriceResult> updateBidPriceResultList = new ArrayList<BidPriceResult>();
				List<BidPriceResult> insertBidPriceResultList = new ArrayList<BidPriceResult>();
				//查询出来当前项目所有供应商的报价
				QueryWrapper<BidPriceResult> queryWrapperOldPriceResul = new QueryWrapper<BidPriceResult>();
				queryWrapperOldPriceResul.lambda().eq(BidPriceResult::getTenderId, tenderId).eq(BidPriceResult::getSupplierId, supplierId);
				List<BidPriceResult> oldBidPriceResultList =bidPriceResultMapper.selectList(queryWrapperOldPriceResul);
				Map<String, BidPriceResult> bidPriceResultMap = new HashMap<String, BidPriceResult>();
				oldBidPriceResultList.forEach(bidPriceResult -> {
 					bidPriceResultMap.put(bidPriceResult.getBidPriceId(), bidPriceResult);
				});
				
				bidPriceHisResultList.forEach(hisResult->{
					BidPriceResult bidPriceResultTemp = bidPriceResultMap.get( hisResult.getBidPriceId());	
					if(null == bidPriceResultTemp) {
						bidPriceResultTemp = new BidPriceResult();
						bidPriceResultTemp.setId(IDUtils.getId());
						bidPriceResultTemp.setTenderId(hisResult.getTenderId());
						bidPriceResultTemp.setSupplierId(hisResult.getSupplierId());
						bidPriceResultTemp.setBidPriceId(hisResult.getBidPriceId());
						bidPriceResultTemp.setBidPriceName(hisResult.getBidPriceName());
						bidPriceResultTemp.setBidPriceType(hisResult.getBidPriceType());
						bidPriceResultTemp.setPriceUnit(hisResult.getPriceUnit());
						bidPriceResultTemp.setBidPriceCode(hisResult.getBidPriceCode());
						bidPriceResultTemp.setPriceContent(hisResult.getPriceContent());
						bidPriceResultTemp.setFinalBidPrice(hisResult.getFinalBidPrice());
						bidPriceResultTemp.setBidPrice(hisResult.getBidPrice());
						bidPriceResultTemp.setEvaluationPrice(hisResult.getEvaluationPrice());
						bidPriceResultTemp.setCreateTime(new Date());
						insertBidPriceResultList.add(bidPriceResultTemp);
					}else {
						bidPriceResultTemp.setBidPriceName(hisResult.getBidPriceName());
						bidPriceResultTemp.setBidPriceType(hisResult.getBidPriceType());
						bidPriceResultTemp.setPriceUnit(hisResult.getPriceUnit());
						bidPriceResultTemp.setBidPriceCode(hisResult.getBidPriceCode());
						bidPriceResultTemp.setPriceContent(hisResult.getPriceContent());
						bidPriceResultTemp.setFinalBidPrice(hisResult.getFinalBidPrice());
						bidPriceResultTemp.setBidPrice(hisResult.getBidPrice());
						bidPriceResultTemp.setEvaluationPrice(hisResult.getEvaluationPrice());
						bidPriceResultTemp.setCreateTime(new Date());
						updateBidPriceResultList.add(bidPriceResultTemp);
					}
				});
				 if(insertBidPriceResultList.size() > 0) {
					 bidPriceResultMapper.insertByBatch(insertBidPriceResultList);			
				 }
				 
				 if(updateBidPriceResultList.size() > 0) {
					 bidPriceResultMapper.updateBatchList(updateBidPriceResultList);				
				 }
				supplierOpeningResultService.updateSupplierSumPrice(tenderId, supplierId, true, true);
			}
//			//判断素有供应是否都完成报价
//			if(true) {
//				//将最后一轮报价赋值给
//				ReBidPriceRound round = reBidPriceRoundMapper.selectById(roundId);
//				reBidPriceRoundService.completeCurrentRound(round);
//			}
			return true;
		}
		return false;
	
	}

}
