package com.gx.obe.server.management.evaluation.service.impl;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.BigDecimalUtils;
import com.gx.obe.server.management.evaluation.dao.EvaluationFactorItemMapper;
import com.gx.obe.server.management.evaluation.entity.EvaluationFactorItem;
import com.gx.obe.server.management.evaluation.service.EvaluationFactorItemService;

/** 
 * @Description: 
 * @author mazc 
 */
@Service
@Transactional
public class EvaluationFactorItemServiceImpl extends ServiceImpl<EvaluationFactorItemMapper, EvaluationFactorItem> implements EvaluationFactorItemService {

	@Autowired
	private EvaluationFactorItemMapper evaluationFactorItemMapper;
	
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeEvaluationFactorItemList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch (List<EvaluationFactorItem> ObeEvaluationFactorItemList){
		return evaluationFactorItemMapper.updateBatchList(ObeEvaluationFactorItemList);
	}
	
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeEvaluationFactorItemList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer insertByBatch (List<EvaluationFactorItem> ObeEvaluationFactorItemList){
		return evaluationFactorItemMapper.insertByBatch(ObeEvaluationFactorItemList);
	}

	@Override
	public BigDecimal getAIScore(String supplierId, String factorCode, String tenderId, BigDecimal highestScore) {
		BigDecimal returnScore = BigDecimal.ZERO;
		QueryWrapper<EvaluationFactorItem> queryWrapper = new QueryWrapper<EvaluationFactorItem>();
		queryWrapper.lambda().eq(EvaluationFactorItem::getFactorCode, factorCode).eq(EvaluationFactorItem::getTenderId, tenderId)
		.eq(EvaluationFactorItem::getSupplierId, supplierId);
		int thisSupplierCount = evaluationFactorItemMapper.selectCount(queryWrapper);
		List<Map<String, Object>> itemMap = evaluationFactorItemMapper.getEvaluationFactorItemCount(tenderId, factorCode);
		long maxCount = 0;
		if(null != itemMap && itemMap.size() >= 2){
			maxCount = Long.parseLong(itemMap.get(itemMap.size() - 1).get("COUNT").toString());
		}
		if(thisSupplierCount == maxCount && thisSupplierCount > 0){
			returnScore = highestScore;
		}else{
			returnScore = BigDecimalUtils.mul(BigDecimalUtils.div(highestScore, new BigDecimal(maxCount)), new BigDecimal(thisSupplierCount));
			returnScore = returnScore.divide(new BigDecimal(1), 1);
		}
		
		return returnScore;
	}

	@Override
	public List<EvaluationFactorItem> getItemByTenderIdAndSupplierIdAndfactorCode(String tenderId, String supplierId, String factorCode) {
		QueryWrapper<EvaluationFactorItem> queryWrapper = new QueryWrapper<EvaluationFactorItem>();
		queryWrapper.lambda().eq(EvaluationFactorItem::getFactorCode, factorCode).eq(EvaluationFactorItem::getTenderId, tenderId)
		.eq(EvaluationFactorItem::getSupplierId, supplierId);
		return evaluationFactorItemMapper.selectList(queryWrapper);
	}

	@Override
	public boolean deleteByTenderId(String tenderId) {
		QueryWrapper<EvaluationFactorItem> queryWrapper = new QueryWrapper<EvaluationFactorItem>();
		queryWrapper.lambda().eq(EvaluationFactorItem::getTenderId, tenderId);
		return evaluationFactorItemMapper.delete(queryWrapper) > 0;
	}
	

}
