package com.gx.obe.server.management.expert.controller;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import com.gx.obe.server.management.evaluation.entity.EvaluationFactorResult;
import com.gx.obe.server.management.supplier.entity.SupplierEvaluationStep;
import com.gx.obe.server.management.vo.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.gx.obe.server.common.base.BaseController;
import com.gx.obe.server.common.enumeration.CommonEnum;
import com.gx.obe.server.common.json.EntityUtill;
import com.gx.obe.server.common.log.OperationType;
import com.gx.obe.server.common.log.SysLogAnnotation;
import com.gx.obe.server.common.vo.RequestBodyEntity;
import com.gx.obe.server.management.check.entity.CheckResult;
import com.gx.obe.server.management.editprice.entity.EditPriceItemResult;
import com.gx.obe.server.management.evaluation.entity.BidPriceResult;
import com.gx.obe.server.management.evaluation.entity.EvaluationStep;
import com.gx.obe.server.management.expert.entity.ExpertEntity;
import com.gx.obe.server.management.expert.entity.ExpertEvaluationResult;
import com.gx.obe.server.management.expert.entity.ExpertEvaluationStep;
import com.gx.obe.server.management.expert.service.ExpertEvaluationStepService;
import com.gx.obe.server.management.supplier.entity.Supplier;
import com.gx.obe.server.management.supplier.entity.SupplierEvaluationResult;

import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;

/**
 * @author mazc
 * @Description: 记录评审成员的评审进度
 */
@Api(tags = "")
@RestController
@AllArgsConstructor
@RequestMapping("/expertEvaluationStep")
public class ExpertEvaluationStepController extends BaseController<ExpertEvaluationStepService, ExpertEvaluationStep> {

    @Autowired
    public ExpertEvaluationStepService expertEvaluationStepService;

    /**
     * @param expertEvaluationStepList
     * @Description: 批量插入
     * @author mazc
     */
    @PostMapping("/insertByBatch")
    public int insertByBatch(@RequestBody List<ExpertEvaluationStep> expertEvaluationStepList) {
        return expertEvaluationStepService.insertByBatch(expertEvaluationStepList);
    }

    /**
     * @param expertEvaluationStepList
     * @Description: 批量更新
     * @author mazc
     */
    @PostMapping("/updateByBatch")
    public int updateByBatch(@RequestBody List<ExpertEvaluationStep> expertEvaluationStepList) {
        return expertEvaluationStepService.updateByBatch(expertEvaluationStepList);
    }

    /**
     * @param tenderId
     * @param userId
     * @return
     * @Description: 获得评审成员的评标步骤列表
     * @author mazc
     */
    @GetMapping("/findExpertEvaluationStepList")
    public List<ExpertEvaluationStep> findExpertEvaluationStepList(String tenderId, String userId) {
        QueryWrapper<ExpertEvaluationStep> wrapper = new QueryWrapper<>();
        wrapper.lambda().eq(ExpertEvaluationStep::getTenderId, tenderId)
                .eq(ExpertEvaluationStep::getUserId, userId);
        return expertEvaluationStepService.list(wrapper);
    }

    /**
     * @param requestBodyEntity
     * @return
     * @Description: 修改专家对当前评标步骤的评审进度
     * @author mazc
     */
    @PostMapping("/updateExpertEvaluationStatus")
    public ExpertEvaluationStep updateExpertEvaluationStatus(@RequestBody RequestBodyEntity<EvaluationStep> requestBodyEntity) {
        String tenderId = (String) requestBodyEntity.getParam("tenderId");
        String userId = (String) requestBodyEntity.getParam("userId");
        String status = (String) requestBodyEntity.getParam("status");
        EvaluationStep evaluationStep = requestBodyEntity.getEntity();
        return expertEvaluationStepService.updateExpertEvaluationStatus(status, tenderId, evaluationStep, userId);
    }

    /**
     * @param saveEvaluationResultVo
     * @return
     * @Description:保存评审结果
     * @author mazc
     */
    @PostMapping("/saveEvaluationResult")
    @SysLogAnnotation(detail="保存评审结果",level = 0,operationType = OperationType.UPDATE)
    public boolean saveEvaluationResult(@RequestBody SaveEvaluationResultVo saveEvaluationResultVo) {
        return expertEvaluationStepService.saveEvaluationResult(saveEvaluationResultVo);
    }

    /**
     * @param submitEvaluationResultVo
     * @return
     * @Description: 提交评标结果
     * @author chenxw
     */
    @PostMapping("/submitEvaluationResult")
    @SysLogAnnotation(detail="提交评标结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitEvaluationResult(@RequestBody SubmitEvaluationResultVo submitEvaluationResultVo) {
        return expertEvaluationStepService.submitEvaluationResult(submitEvaluationResultVo);
    }

    /**
     * @param tenderId
     * @param stepId
     * @param userId
     * @return
     * @Description: 获得评审成员对指定项目的指定的评标步骤
     * @author chenxw
     */
    @GetMapping("/getExpertEvaluationStep")
    public ExpertEvaluationStep getExpertEvaluationStep(String tenderId, String stepId, String userId) {
        QueryWrapper<ExpertEvaluationStep> wrapper = new QueryWrapper<>();
        wrapper.lambda().eq(ExpertEvaluationStep::getTenderId, tenderId)
                .eq(ExpertEvaluationStep::getStepId, stepId)
                .eq(ExpertEvaluationStep::getUserId, userId);
        return expertEvaluationStepService.getOne(wrapper);
    }

    /**
     * @param tenderId
     * @param stepId
     * @return
     * @Description: 获得指定评标步骤的评审记录
     * @author chenxw
     */
    @GetMapping("/getEvaluationStepListByStepId")
    public List<ExpertEvaluationStep> getEvaluationStepListByStepId(String tenderId, String stepId) {
        QueryWrapper<ExpertEvaluationStep> wrapper = new QueryWrapper<>();
        wrapper.lambda().eq(ExpertEvaluationStep::getTenderId, tenderId)
                .eq(ExpertEvaluationStep::getStepId, stepId);
        return expertEvaluationStepService.list(wrapper);
    }

    /**
     * @param requestBodyEntity
     * @Description: 预评审审核通过
     * @author chenxw
     */
    @PostMapping("/preEvaluationAuditAdopt")
    public void preEvaluationAuditAdopt(@RequestBody RequestBodyEntity<EvaluationStep> requestBodyEntity) {
        String tenderId = (String) requestBodyEntity.getParam("tenderId");
        String userId = (String) requestBodyEntity.getParam("userId");
        expertEvaluationStepService.updateExpertEvaluationStatus(CommonEnum.COMPLETE, tenderId, requestBodyEntity.getEntity(), userId);

    }

    /**
     * @param tenderId
     * @param userId
     * @param stepId
     * @param message
     * @Description: 预评审审核退回
     * @author chenxw
     */
    @GetMapping("/preEvaluationAuditReturn")
    @SysLogAnnotation(detail="预评审审核退回",level = 0,operationType = OperationType.UPDATE)
    public void preEvaluationAuditReturn(String tenderId, String userId, String stepId, String message) {
        UpdateWrapper<ExpertEvaluationStep> wrapper = new UpdateWrapper<>();
        wrapper.lambda().set(ExpertEvaluationStep::getStepStatus, CommonEnum.IN_PROGRESS)
                .set(ExpertEvaluationStep::getApplyReason, message)
                .eq(ExpertEvaluationStep::getTenderId, tenderId)
                .eq(ExpertEvaluationStep::getUserId, userId)
                .eq(ExpertEvaluationStep::getStepId, stepId);
        expertEvaluationStepService.update(wrapper);
    }

    /**
     * @param tenderId
     * @param sort
     * @param userId
     * @return
     * @Description: 获得评审成员对指定项目的指定序号的评标步骤
     * @author wangxiang
     */
    @GetMapping("/getExpertEvaluationStepBySort")
    public ExpertEvaluationStep getExpertEvaluationStepBySort(String tenderId, int sort, String userId) {
        return expertEvaluationStepService.getExpertEvaluationStepBySort(tenderId, sort, userId);
    }

    /**
     * @param requestBody
     * @return
     * @Description: 评标专家签到
     * @author wangxiang
     */
    @GetMapping("/expertAvoid")
    @SysLogAnnotation(detail="评标专家回避",level = 0,operationType = OperationType.UPDATE)
    public boolean expertAvoid(@RequestBody RequestBodyEntity<EvaluationStep> requestBody) {
        return true;
    }

    /**
     * @param tenderId
     * @param stepId
     * @return
     * @Description: 获得某一评标步骤评标专家评审完成的数量
     * @author wangxiang
     */
    @GetMapping("/getExpertEvaluationComplateCount")
    public int getExpertEvaluationComplateCount(String tenderId, String stepId) {
        return expertEvaluationStepService.getExpertEvaluationComplateCount(tenderId, stepId);
    }

    /**
     * @param requestBody
     * @return
     * @Description: 评标专家签到
     * @author wangxiang
     */
    @PostMapping("/submitExpertSignEvaluation")
    @SysLogAnnotation(detail="评标专家签到",level = 0,operationType = OperationType.UPDATE)
    public boolean submitExpertSignEvaluation(@RequestBody RequestBodyEntity<EvaluationStep> requestBody) {
        String tenderId = (String) requestBody.getParam("tenderId");
        String userId = (String) requestBody.getParam("userId");
        EvaluationStep evaluationStep = requestBody.getEntity();
        String signType = (String) requestBody.getParam("signType");
        String signResult = (String) requestBody.getParam("signResult");
        return expertEvaluationStepService.submitExpertSignEvaluation(tenderId, userId, evaluationStep, signType, signResult);
    }

    /**
     * @param requestBody
     * @return
     * @Description: 提交推荐中标候选人结果
     * @author wangxiang
     */
    @PostMapping("/submitRecommonedEvaluationResult")
    @SysLogAnnotation(detail="提交推荐中标候选人结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitRecommonedEvaluationResult(@RequestBody RequestBodyEntity<EvaluationStep> requestBody) {
        String tenderId = (String) requestBody.getParam("tenderId");
        String userId = (String) requestBody.getParam("userId");
        String evaluationOpinion = (String) requestBody.getParam("evaluationOpinion");
        EvaluationStep evaluationStep = requestBody.getEntity();
        List<Object> objList = requestBody.getList();
        List<SupplierEvaluationResult> supplierEvalResultList = new ArrayList<>();
        if (null != objList && objList.size() > 0) {
            for (Object obj : objList) {
                supplierEvalResultList.add(EntityUtill.toBean((Map<String, Object>) obj, SupplierEvaluationResult.class));
            }
        }
        return expertEvaluationStepService.submitRecommonedEvaluationResult(tenderId, userId, evaluationOpinion, evaluationStep, supplierEvalResultList);
    }

    /**
     * @param saveFeatureEvaluationResultVo
     * @return
     * @Description: 保存特征码检查结果
     * @author wangxiang
     */
    @PostMapping("/saveFeatureEvaluationResult")
    @SysLogAnnotation(detail="保存特征码检查结果",level = 0,operationType = OperationType.UPDATE)
    public boolean saveFeatureEvaluationResult(@RequestBody SaveFeatureEvaluationResultVo saveFeatureEvaluationResultVo) {
        String tenderId = saveFeatureEvaluationResultVo.getTenderId();
        String userId = saveFeatureEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = saveFeatureEvaluationResultVo.getEvaluationStep();
        List<CheckResult> checkResultList = saveFeatureEvaluationResultVo.getCheckResultList();
        List<ExpertEvaluationResult> expertEvaluationResultList = saveFeatureEvaluationResultVo.getExpertEvaluationResultList();
        return expertEvaluationStepService.saveFeatureEvaluationResult(tenderId, userId, evaluationStep, checkResultList, expertEvaluationResultList);
    }

    /**
     * @param submitFeatureEvaluationResultVo
     * @return
     * @Description: 提交特征码检查结果
     * @author wangxiang
     */
    @PostMapping("/submitFeatureEvaluationResult")
    @SysLogAnnotation(detail="提交特征码检查结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitFeatureEvaluationResult(@RequestBody SubmitFeatureEvaluationResultVo submitFeatureEvaluationResultVo) {
        String tenderId = submitFeatureEvaluationResultVo.getTenderId();
        String userId = submitFeatureEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = submitFeatureEvaluationResultVo.getEvaluationStep();
        List<Supplier> supplierList = submitFeatureEvaluationResultVo.getSupplierList();
        return expertEvaluationStepService.submitFeatureEvaluationResult(tenderId, userId, evaluationStep, supplierList);

    }

    /**
     * @param saveLimitPriceEvaluationResultvo
     * @return
     * @Description: 保存限价检查结果
     * @author wangxiang
     */
    @PostMapping("/saveLimitPriceEvaluationResult")
    @SysLogAnnotation(detail="保存限价检查结果",level = 0,operationType = OperationType.UPDATE)
    public boolean saveLimitPriceEvaluationResult(@RequestBody SaveLimitPriceEvaluationResultVo saveLimitPriceEvaluationResultvo) {
        String tenderId = saveLimitPriceEvaluationResultvo.getTenderId();
        String userId = saveLimitPriceEvaluationResultvo.getUserId();
        EvaluationStep evaluationStep = saveLimitPriceEvaluationResultvo.getEvaluationStep();
        Map<String, ExpertEvaluationResult> expertEvaluationResultMap = saveLimitPriceEvaluationResultvo.getExpertEvaluationResultMap();
        return expertEvaluationStepService.saveLimitPriceEvaluationResult(tenderId, userId, evaluationStep, expertEvaluationResultMap);
    }

    /**
     * @param submitFeatureEvaluationResultVo
     * @return
     * @Description: 提交限价检查结果
     * @author wangxiang
     */
    @PostMapping("/submitLimitPriceEvaluationResult")
    @SysLogAnnotation(detail="提交限价检查结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitLimitPriceEvaluationResult(@RequestBody SubmitFeatureEvaluationResultVo submitFeatureEvaluationResultVo) {
        String tenderId = submitFeatureEvaluationResultVo.getTenderId();
        String userId = submitFeatureEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = submitFeatureEvaluationResultVo.getEvaluationStep();
        List<Supplier> supplierList = submitFeatureEvaluationResultVo.getSupplierList();
        return expertEvaluationStepService.submitLimitPriceEvaluationResult(tenderId, userId, evaluationStep, supplierList);

    }

    /**
     * @param tenderId
     * @param stepId
     * @param nodeSortNo
     * @param ifFilter
     * @Description: 重新授权专家的评标步骤
     * @author wangxiang
     */
    @GetMapping("/reBackExpertEvaluationStep")
    @SysLogAnnotation(detail="重新授权专家的评标步骤",level = 0,operationType = OperationType.UPDATE)
    public boolean reBackExpertEvaluationStep(String tenderId, String stepId, int nodeSortNo, boolean ifFilter, String userId) {
        return expertEvaluationStepService.reBackExpertEvaluationStep(tenderId, stepId, nodeSortNo, ifFilter, userId);
    }

    /**
     * @param status
     * @param tenderId
     * @param stepId
     * @param userId
     * @return
     * @Description: 修改专家确认评标价的状态
     * @author wangxiang
     */
    @GetMapping("/updateEvalPriceConfirmStatus")
    @SysLogAnnotation(detail="修改专家确认评标价的状态",level = 0,operationType = OperationType.UPDATE)
    public boolean updateEvalPriceConfirmStatus(String status, String tenderId, String stepId, String userId) {
        UpdateWrapper<ExpertEvaluationStep> wraaper = new UpdateWrapper<>();
        wraaper.lambda().set(ExpertEvaluationStep::getPriceConfirmStatus, status)
                .eq(ExpertEvaluationStep::getTenderId, tenderId)
                .eq(ExpertEvaluationStep::getStepId, stepId)
                .eq(ExpertEvaluationStep::getUserId, userId);
        return expertEvaluationStepService.update(wraaper);
    }

    /**
     * @param tenderId
     * @param stepId
     * @return
     * @Description: 获得专家确认修正评标价结果列表
     * @author guoyr
     */
    @GetMapping("/getEvalPriceConfirmList")
    public List<ExpertEvaluationStep> getEvalPriceConfirmList(String tenderId, String stepId) {
        return expertEvaluationStepService.getEvalPriceConfirmList(tenderId, stepId);
    }

    /**
     * @param tenderId
     * @param stepId
     * @return
     * @Description: 验证是否已经保存过修正评标价
     * @author wangxiang
     */
    @GetMapping("/isSaveCorrectEvalPrice")
    public boolean isSaveCorrectEvalPrice(String tenderId, String stepId) {
        QueryWrapper<ExpertEvaluationStep> wraaper = new QueryWrapper<>();
        wraaper.lambda().eq(ExpertEvaluationStep::getTenderId, tenderId)
                .eq(ExpertEvaluationStep::getStepId, stepId)
                .eq(ExpertEvaluationStep::getPriceConfirmStatus, CommonEnum.YES);
        return expertEvaluationStepService.count(wraaper) > 0;
    }

    /**
     * @param tenderId
     * @param stepId
     * @return
     * @Description: 获得步骤下已经评审完毕的专家
     * @author wangxiang
     */
    @GetMapping("/getExpertListByStepFinish")
    public List<ExpertEntity> getExpertListByStepFinish(String tenderId, String stepId) {
        return expertEvaluationStepService.getExpertListByStepFinish(tenderId, stepId);
    }

    /**
     * 保存推荐排名结果
     *
     * @return
     * @Description:
     * @author wangxiang
     */
    @PostMapping("/saveRecommendRankEvaluationResult")
    @SysLogAnnotation(detail="保存推荐排名结果",level = 0,operationType = OperationType.UPDATE)
    public boolean saveRecommendRankEvaluationResult(@RequestBody SaveRecommendRankEvaluationResultVo saveRecommendRankEvaluationResultVo) {
        String tenderId = saveRecommendRankEvaluationResultVo.getTenderId();
        String userId = saveRecommendRankEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = saveRecommendRankEvaluationResultVo.getEvaluationStep();
        List<ExpertEvaluationResult> expertEvaluationResultList = saveRecommendRankEvaluationResultVo.getExpertEvaluationResultList();
        return expertEvaluationStepService.saveRecommendRankEvaluationResult(tenderId, userId, evaluationStep, expertEvaluationResultList);
    }

    /**
     * @param submitRecommendRankEvaluationResultVo
     * @return
     * @Description: 提交推荐排名结果
     * @author wangxiang
     */
    @PostMapping("/submitRecommendRankEvaluationResult")
    @SysLogAnnotation(detail="提交推荐排名结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitRecommendRankEvaluationResult(@RequestBody SubmitRecommendRankEvaluationResultVo submitRecommendRankEvaluationResultVo) {
        String tenderId = submitRecommendRankEvaluationResultVo.getTenderId();
        String userId = submitRecommendRankEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = submitRecommendRankEvaluationResultVo.getEvaluationStep();
        List<Supplier> supplierList = submitRecommendRankEvaluationResultVo.getSupplierList();
        int count = submitRecommendRankEvaluationResultVo.getCount();
        return expertEvaluationStepService.submitRecommendRankEvaluationResultVo(tenderId, userId, evaluationStep, supplierList, count);
    }

    /**
     * @param saveLimitPriceEvaluationResultvo
     * @return
     * @Description: 保存否決投标
     * @author wangxiang
     */
    @PostMapping("/saveVetoBidEvaluationResult")
    @SysLogAnnotation(detail="保存否決投标",level = 0,operationType = OperationType.UPDATE)
    public boolean saveVetoBidEvaluationResult(@RequestBody SaveLimitPriceEvaluationResultVo saveLimitPriceEvaluationResultvo) {
        String tenderId = saveLimitPriceEvaluationResultvo.getTenderId();
        String userId = saveLimitPriceEvaluationResultvo.getUserId();
        EvaluationStep evaluationStep = saveLimitPriceEvaluationResultvo.getEvaluationStep();
        Map<String, ExpertEvaluationResult> expertEvaluationResultMap = saveLimitPriceEvaluationResultvo.getExpertEvaluationResultMap();
        return expertEvaluationStepService.saveVetoBidEvaluationResult(tenderId, userId, evaluationStep, expertEvaluationResultMap);
    }

    /**
     * @param submitFeatureEvaluationResultVo
     * @return
     * @Description:提交否决投标结果
     * @author wangxiang
     */
    @PostMapping("/submitVetoBidEvaluationResult")
    @SysLogAnnotation(detail="提交否决投标结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitVetoBidEvaluationResult(@RequestBody SubmitFeatureEvaluationResultVo submitFeatureEvaluationResultVo) {
        String tenderId = submitFeatureEvaluationResultVo.getTenderId();
        String userId = submitFeatureEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = submitFeatureEvaluationResultVo.getEvaluationStep();
        List<Supplier> supplierList = submitFeatureEvaluationResultVo.getSupplierList();
        return expertEvaluationStepService.submitVetoBidEvaluationResult(tenderId, userId, evaluationStep, supplierList);
    }

    /**
     * @return
     * @Description: 保存信用得分结果
     * @author wangxiang
     */
    @PostMapping("/submitCreditEvaluationResult")
    @SysLogAnnotation(detail="保存信用得分结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitCreditEvaluationResult(@RequestBody SubmitCreditEvaluationResultVo submitCreditEvaluationResultVo) {
        String tenderId = submitCreditEvaluationResultVo.getTenderId();
        String userId = submitCreditEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = submitCreditEvaluationResultVo.getEvaluationStep();
        List<Supplier> supplierList = submitCreditEvaluationResultVo.getSupplierList();
        Map<String, ExpertEvaluationResult> expertEvaluationResultMap = submitCreditEvaluationResultVo.getExpertEvaluationResultMap();
        return expertEvaluationStepService.submitCreditEvaluationResult(tenderId, userId, evaluationStep, supplierList, expertEvaluationResultMap);
    }

    /**
     * @param saveLimitPriceEvaluationResultvo
     * @return
     * @Description: 保存清单评审结果
     * @author wangxiang
     */
    @PostMapping("/saveBillEvaluationResult")
    @SysLogAnnotation(detail="保存清单评审结果",level = 0,operationType = OperationType.UPDATE)
    public boolean saveBillEvaluationResult(@RequestBody SaveLimitPriceEvaluationResultVo saveLimitPriceEvaluationResultvo) {
        String tenderId = saveLimitPriceEvaluationResultvo.getTenderId();
        String userId = saveLimitPriceEvaluationResultvo.getUserId();
        EvaluationStep evaluationStep = saveLimitPriceEvaluationResultvo.getEvaluationStep();
        Map<String, ExpertEvaluationResult> expertEvaluationResultMap = saveLimitPriceEvaluationResultvo.getExpertEvaluationResultMap();
        return expertEvaluationStepService.saveBillEvaluationResult(tenderId, userId, evaluationStep, expertEvaluationResultMap);
    }

    /**
     * @param requestBodyEntity
     * @return
     * @Description: 提交多轮报价结果
     * @author wangxiang
     */
    @PostMapping("/submitMultiPriceResult")
    @SysLogAnnotation(detail="提交多轮报价结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitMultiPriceResult(@RequestBody RequestBodyEntity<EvaluationStep> requestBodyEntity) {
        String tenderId = (String) requestBodyEntity.getParam("tenderId");
        String userId = (String) requestBodyEntity.getParam("userId");
        String status = (String) requestBodyEntity.getParam("status");
        EvaluationStep evaluationStep = requestBodyEntity.getEntity();
        return expertEvaluationStepService.submitMultiPriceResult(status, tenderId, evaluationStep, userId);

    }

    /**
     * @param tenderId
     * @param userId
     * @param curStepIndex
     * @return
     * @Description: 获得当前评标步骤之前未完成评审的个数
     * @author wangxiang
     */
    @GetMapping("/getNotComplateStepCount")
    public Integer getNotComplateStepCount(String tenderId, String userId, int curStepIndex) {
        return expertEvaluationStepService.getNotComplateStepCount(tenderId, userId, curStepIndex);
    }

    /**
     * @return
     * @Description: 保存合量评审结果
     * @author wangxiang
     */
    @PostMapping("/saveTotalPriceEvaluationResult")
    @SysLogAnnotation(detail="保存合量评审结果",level = 0,operationType = OperationType.UPDATE)
    public boolean saveTotalPriceEvaluationResult(@RequestBody SubmitCreditEvaluationResultVo submitCreditEvaluationResultVo) {
        String id = submitCreditEvaluationResultVo.getTenderId();
        String commonExpert = submitCreditEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = submitCreditEvaluationResultVo.getEvaluationStep();
        List<Supplier> supplierList = submitCreditEvaluationResultVo.getSupplierList();
        Map<String, ExpertEvaluationResult> expertEvaluationResultMap = submitCreditEvaluationResultVo.getExpertEvaluationResultMap();
        return expertEvaluationStepService.saveTotalPriceEvaluationResult(id, commonExpert, evaluationStep, supplierList, expertEvaluationResultMap);
    }

    /**
     * @param submitFeatureEvaluationResultVo
     * @return
     * @Description:提交否决投标结果
     * @author wangxiang
     */
    @PostMapping("/submitTotalPriceEvaluationResult")
    @SysLogAnnotation(detail="提交否决投标结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitTotalPriceEvaluationResult(@RequestBody SubmitFeatureEvaluationResultVo submitFeatureEvaluationResultVo) {
        String tenderId = submitFeatureEvaluationResultVo.getTenderId();
        String userId = submitFeatureEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = submitFeatureEvaluationResultVo.getEvaluationStep();
        List<Supplier> supplierList = submitFeatureEvaluationResultVo.getSupplierList();
        return expertEvaluationStepService.submitTotalPriceEvaluationResult(tenderId, userId, evaluationStep, supplierList);
    }

    /**
     * @param requestBodyEntity
     * @return
     * @Description: 提交预评审结果
     * @author wangxiang
     */
    @PostMapping("/submitPreEvaluationResult")
    @SysLogAnnotation(detail="提交预评审结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitPreEvaluationResult(@RequestBody RequestBodyEntity<EvaluationStep> requestBodyEntity) {
        String tenderId = (String) requestBodyEntity.getParam("tenderId");
        EvaluationStep evaluationStep = requestBodyEntity.getEntity();
        return expertEvaluationStepService.submitPreEvaluationResult(tenderId, evaluationStep);

    }

    /**
     * @param saveEditPriceResultVo
     * @return
     * @Description: 保存修正报价结果
     * @author wangxiang
     */
    @PostMapping("/saveEditPriceResult")
    @SysLogAnnotation(detail="保存修正报价结果",level = 0,operationType = OperationType.UPDATE)
    public boolean saveEditPriceResult(@RequestBody SaveEditPriceResultVo saveEditPriceResultVo) {
        String tenderId = saveEditPriceResultVo.getTenderId();
        EvaluationStep evaluationStep = saveEditPriceResultVo.getEvaluationStep();
        List<EditPriceItemResult> editPriceItemResultList = saveEditPriceResultVo.getEditPriceItemResultList();
        List<BidPriceResult> bidPriceResultList = saveEditPriceResultVo.getBidPriceResultList();
        return expertEvaluationStepService.submitTotalPriceEvaluationResult(tenderId, evaluationStep, editPriceItemResultList, bidPriceResultList);
    }

    /**
     * @param requestBodyEntity
     * @return
     * @Description: 提交修正报价结果
     * @author wangxiang
     */
    @PostMapping("/submitEditPriceResult")
    @SysLogAnnotation(detail="提交修正报价结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitEditPriceResult(@RequestBody RequestBodyEntity<EvaluationStep> requestBodyEntity) {
        String tenderId = (String) requestBodyEntity.getParam("tenderId");
        String userId = (String) requestBodyEntity.getParam("userId");
        EvaluationStep evaluationStep = requestBodyEntity.getEntity();
        return expertEvaluationStepService.submitEditPriceResult(tenderId, evaluationStep, userId);
    }

    /**
     * @param tenderId
     * @param stepType
     * @return
     * @Description: 根据步骤类型获取审核列表
     * @author chenxw
     */
    @GetMapping("/getAuditListByStepType")
    public List<Audit> getAuditListByStepType(String tenderId, String stepType) {
        return expertEvaluationStepService.getAuditListByStepType(tenderId, stepType);
    }

    /**
     * @param updateAssignPropertyVo
     * @return
     * @Description: 指定字段修改
     * @author chenxw
     */
    @PostMapping("/updateAssignProperty")
    @SysLogAnnotation(detail="指定字段修改专家评标结果",level = 0,operationType = OperationType.UPDATE)
    public boolean updateAssignProperty(@RequestBody UpdateAssignPropertyVo<ExpertEvaluationStep> updateAssignPropertyVo) {
        ExpertEvaluationStep expertEvaluationStep = updateAssignPropertyVo.getEntity();
        String[] attributes = updateAssignPropertyVo.getAttributes();
        return expertEvaluationStepService.updateAssignProperty(expertEvaluationStep, attributes);
    }

    /**
     * @param tenderId
     * @param stepType
     * @Description: 根据步骤类型删除专家评审步骤
     * @author chenxw
     */
    @GetMapping("/deleteExpertEvaluationStepByStepType")
    @SysLogAnnotation(detail="根据步骤类型删除专家评审步骤",level = 0,operationType = OperationType.DELETE)
    public void deleteExpertEvaluationStepByStepType(String tenderId, String stepType) {
        expertEvaluationStepService.deleteExpertEvaluationStepByStepType(tenderId, stepType);
    }

    /**
     * @param saveCleanTenderEvaluationResultVo
     * @return
     * @Description: 保存清标检查结果
     * @author guoyr
     */
    @PostMapping("/saveCleanTenderEvaluationResult")
    @SysLogAnnotation(detail="保存清标检查结果",level = 0,operationType = OperationType.UPDATE)
    public boolean saveCleanTenderEvaluationResult(@RequestBody SaveCleanTenderEvaluationResultVo saveCleanTenderEvaluationResultVo) {
        String tenderId = saveCleanTenderEvaluationResultVo.getTenderId();
        String userId = saveCleanTenderEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = saveCleanTenderEvaluationResultVo.getEvaluationStep();
        List<ExpertEvaluationResult> expertEvaluationResultList = saveCleanTenderEvaluationResultVo.getExpertEvaluationResultList();
        return expertEvaluationStepService.saveCleanTenderEvaluationResult(tenderId, userId, evaluationStep, expertEvaluationResultList);
    }

    /**
     * @param submitCleanTenderEvaluationResultVo
     * @return
     * @Description: 提交清标检查结果
     * @author guoyr
     */
    @PostMapping("/submitCleanTenderEvaluationResult")
    @SysLogAnnotation(detail="提交清标检查结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitCleanTenderEvaluationResult(@RequestBody SubmitCleanTenderEvaluationResultVo submitCleanTenderEvaluationResultVo) {
        String tenderId = submitCleanTenderEvaluationResultVo.getTenderId();
        String userId = submitCleanTenderEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = submitCleanTenderEvaluationResultVo.getEvaluationStep();
        ExpertEvaluationStep expertEvaluationStep = submitCleanTenderEvaluationResultVo.getExpertEvaluationStep();
        List<Supplier> supplierList = submitCleanTenderEvaluationResultVo.getSupplierList();
        return expertEvaluationStepService.submitCleanTenderEvaluationResult(tenderId, userId, evaluationStep, expertEvaluationStep, supplierList);
    }

    /**
     * @Description: 保存商务否决评审结果
     * @author chenxw
     * @param saveBusinessVetoEvaluationResultVo
     * @return
     */
    @PostMapping("/saveBusinessVetoEvaluationResult")
    @SysLogAnnotation(detail="保存否决评审结果",level = 0,operationType = OperationType.UPDATE)
    public boolean saveBusinessVetoEvaluationResult(@RequestBody SaveBusinessVetoEvaluationResultVo saveBusinessVetoEvaluationResultVo) {
        String tenderId = saveBusinessVetoEvaluationResultVo.getTenderId();
        EvaluationStep evaluationStep = saveBusinessVetoEvaluationResultVo.getEvaluationStep();
        String userId = saveBusinessVetoEvaluationResultVo.getUserId();
        List<ExpertEvaluationResult> expertEvaluationResultList = saveBusinessVetoEvaluationResultVo.getExpertEvaluationResultList();
        return expertEvaluationStepService.saveBusinessVetoEvaluationResult(tenderId, evaluationStep, userId, expertEvaluationResultList);
    }

    /**
     * @Description: 提交商务否决评审结果
     * @author chenxw
     * @param submitBusinessVetoEvaluationResultVo
     * @return
     */
    @PostMapping("/submitBusinessVetoEvaluationResult")
    @SysLogAnnotation(detail="提交否决评审结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitBusinessVetoEvaluationResult(@RequestBody SubmitBusinessVetoEvaluationResultVo submitBusinessVetoEvaluationResultVo) {
        String tenderId = submitBusinessVetoEvaluationResultVo.getTenderId();
        EvaluationStep evaluationStep = submitBusinessVetoEvaluationResultVo.getEvaluationStep();
        String userId = submitBusinessVetoEvaluationResultVo.getUserId();
        List<Supplier> supplierList = submitBusinessVetoEvaluationResultVo.getSupplierList();
        return expertEvaluationStepService.submitBusinessVetoEvaluationResult(tenderId, evaluationStep, userId, supplierList);
    }

    /**
     * @Description: 保存商务评审结果
     * @author chenxw
     * @param saveBusinessEvaluationResultVo
     * @return
     */
    @PostMapping("/saveBusinessEvaluationResult")
    @SysLogAnnotation(detail="保存商务评审结果",level = 0,operationType = OperationType.UPDATE)
    public boolean saveBusinessEvaluationResult(@RequestBody SaveBusinessEvaluationResultVo saveBusinessEvaluationResultVo) {
        String tenderId = saveBusinessEvaluationResultVo.getTenderId();
        String userId = saveBusinessEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = saveBusinessEvaluationResultVo.getEvaluationStep();
        List<EvaluationFactorResult> evaluationFactorResultList = saveBusinessEvaluationResultVo.getEvaluationFactorResultList();
        List<ExpertEvaluationResult> expertEvaluationResultList = saveBusinessEvaluationResultVo.getExpertEvaluationResultList();
        return expertEvaluationStepService.saveBusinessEvaluationResult(tenderId, userId, evaluationStep, evaluationFactorResultList, expertEvaluationResultList);
    }

    /**
     * @Description: 提交商务评审结果
     * @author chenxw
     * @param submitBusinessEvaluationResultVo
     * @return
     */
    @PostMapping("/submitBusinessEvaluationResult")
    @SysLogAnnotation(detail="提交商务评审结果",level = 0,operationType = OperationType.UPDATE)
    public boolean submitBusinessEvaluationResult(@RequestBody SubmitBusinessEvaluationResultVo submitBusinessEvaluationResultVo) {
        String tenderId = submitBusinessEvaluationResultVo.getTenderId();
        String userId = submitBusinessEvaluationResultVo.getUserId();
        EvaluationStep evaluationStep = submitBusinessEvaluationResultVo.getEvaluationStep();
        List<SupplierEvaluationStep> supplierEvaluationStepList = submitBusinessEvaluationResultVo.getSupplierEvaluationStepList();
        return expertEvaluationStepService.submitBusinessEvaluationResult(tenderId, userId, evaluationStep, supplierEvaluationStepList);
    }

    @GetMapping("/submitEvaluationStep")
    public boolean submitEvaluationStep(String tenderId, String stepId, String userId) {
        return expertEvaluationStepService.submitEvaluationStep(tenderId, stepId, userId);
    }

}