package com.gx.obe.server.management.im.controller;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gx.obe.server.common.base.BaseController;
import com.gx.obe.server.management.im.entity.Employee;
import com.gx.obe.server.management.im.service.EmployeeService;
import com.gx.obe.server.management.im.vo.SaveEmployeeVo;
import com.gx.obe.server.management.supplier.entity.Supplier;
import com.gx.obe.server.management.vo.UpdateAssignPropertyVo;

import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;
/** 
 * @Description: 
 * @author mazc 
 */
@Api(tags = "")
@RestController
@AllArgsConstructor
@RequestMapping("/im/employee")
public class EmployeeController extends BaseController<EmployeeService,Employee>{
	@Autowired
	public EmployeeService employeeServices;
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param EmployeeList 
	 */
	@PostMapping("/insertByBatch")
	public int insertByBatch(@RequestBody List<Employee> EmployeeList) {
		return employeeServices.insertByBatch(EmployeeList);
	}
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param EmployeeList 
	 */
	@PostMapping("/updateByBatch")
	public int updateByBatch(@RequestBody List<Employee> EmployeeList) {
		return employeeServices.updateByBatch(EmployeeList);
	}

	
	 /**
     * @Description: 获得最大的员工编号
     * @author mazc
     * @return 
     */
	@GetMapping("/getMaxEmployeeNumber")
    public int getMaxEmployeeNumber() {
		return employeeServices.getMaxEmployeeNumber();
    }
	
	/**
	 * @Description:  保存员工
	 * @author mazc
	 * @param employee
	 * @param assignedDepartmentIdList
	 * @return 
	 */
	@PostMapping("/saveEmployee")
	public Employee saveEmployee(@RequestBody SaveEmployeeVo saveEmployeeVo) {
		return employeeServices.saveEmployee(saveEmployeeVo.getEmployee(), saveEmployeeVo.getAssignedDepartmentIdList());
	}

	/**
	 * @Description: 获得部门的员工
	 * @author mazc
	 * @param depId
	 * @param isDirect
	 * @return 
	 */
	@GetMapping("/getEmployeeOfDepartment")
	public List<Employee> getEmployeeOfDepartment(String depId, boolean isDirect){
		return employeeServices.getEmployeeOfDepartment(depId, isDirect);
	}
	
	/**
	 * @Description:  获得群成员
	 * @author mazc
	 * @param groupId
	 * @return 
	 */
	@GetMapping("/getEmployeeOfGroup")
	public List<Employee> getEmployeeOfGroup(String groupId){
		return employeeServices.getEmployeeOfGroup(groupId);
	}
	
	@GetMapping("/getEmployeeByLineStatus")
	public List<Employee> getEmployeeByLineStatus(String lineStatus) {
		return employeeServices.getEmployeeByLineStatus(lineStatus);
	}
	
	@PostMapping("/updateAssignProperty")
    public boolean updateAssignProperty(@RequestBody UpdateAssignPropertyVo<Employee> updateAssignPropertyVo) {
		Employee supplier = updateAssignPropertyVo.getEntity();
        String[] attributes = updateAssignPropertyVo.getAttributes();
        return employeeServices.updateAssignProperty(supplier, attributes);
    }
	
	@PostMapping("/updateLineStatusById")
	public void updateLineStatusById(String id,String status) {
		employeeServices.updateLineStatusById(id, status);
	}
	
	
}