package com.gx.obe.server.management.im.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.im.dao.GroupItemMapper;
import com.gx.obe.server.management.im.entity.Employee;
import com.gx.obe.server.management.im.entity.GroupItem;
import com.gx.obe.server.management.im.service.GroupItemService;

/** 
 * @Description: 
 * @author mazc 
 */
@Service
public class GroupItemServiceImpl extends ServiceImpl<GroupItemMapper, GroupItem> implements GroupItemService {

	@Autowired
	private GroupItemMapper groupItemMapper;
	
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param GroupItemList 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch(List<GroupItem> GroupItemList) {
		return groupItemMapper.updateBatchList(GroupItemList);
	}
	
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param GroupItemList 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public Integer insertByBatch(List<GroupItem> GroupItemList) {
		return groupItemMapper.insertByBatch(GroupItemList);
	}
	
	/**
     * @Description: 指定字段修改
     * @author chenxw
     * @param GroupItem
	 * @param attributes
     */
	@Override
    public boolean updateAssignProperty(GroupItem GroupItem, String[] attributes) {
		return groupItemMapper.updateAssignProperty(GroupItem, attributes) > 0;
	}
    
    /**
     * @Description: 批量指定字段修改
     * @author chenxw
     * @param GroupItemList
	 * @param attributes
     */
	@Override
    public Integer batchUpdateProperty(List<GroupItem> GroupItemList, String[] attributes) {
		return groupItemMapper.batchUpdateProperty(GroupItemList, attributes);
	}
	
	/** 
	 * @Description: 批量添加或跟新
	 * @author chenxw
	 * @param GroupItemList
	 * @param attributes
	 * @return 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
    public Integer batchSaveOrUpdate(List<GroupItem> GroupItemList, String[] attributes) {
        List<GroupItem> insertGroupItemList = new ArrayList<>();
        List<GroupItem> updateGroupItemList = new ArrayList<>();
        for (GroupItem GroupItem : GroupItemList) {
            if (StringUtils.isEmpty(GroupItem.getId())) {
                GroupItem.setId(IDUtils.getId());
                insertGroupItemList.add(GroupItem);
            } else {
                updateGroupItemList.add(GroupItem);
            }
        }
        int count = 0;
        if (insertGroupItemList.size() > 0) {
            count += groupItemMapper.insertByBatch(insertGroupItemList);
        }
        if (updateGroupItemList.size() > 0) {
            count += groupItemMapper.batchUpdateProperty(updateGroupItemList, attributes);
        }
        return count;
    }

	@Override
	public List<Employee> getGroupItemByGroupId(String groupId) {
		return groupItemMapper.getGroupItemByGroupId(groupId);
	}

	@Override
	public List<Object> getUserIdListByGroupId(String groupId) {
		QueryWrapper<GroupItem> queryWrapper = new QueryWrapper<GroupItem>();
		queryWrapper.lambda().select(GroupItem::getUserId).eq(GroupItem::getGroupId, groupId);
		return groupItemMapper.selectObjs(queryWrapper);
	}

}
