package com.gx.obe.server.management.other.service;

import java.util.Date;
import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.gx.obe.server.management.other.entity.SignatureFile;
import com.gx.obe.server.management.other.entity.SignatureUser;

/**
 * @author mazc
 * @Description:
 */
public interface SignatureFileService extends IService<SignatureFile> {
    /**
     * @param ObeSignatureFileList
     * @Description: 批量更新
     * @author mazc
     */
    Integer updateByBatch(List<SignatureFile> ObeSignatureFileList);

    /**
     * @param ObeSignatureFileList
     * @Description: 批量插入
     * @author mazc
     */
    Integer insertByBatch(List<SignatureFile> ObeSignatureFileList);

    /**
     * @param ObeSignatureFile
     * @param attributes
     * @Description: 指定字段修改
     * @author chenxw
     */
    boolean updateAssignProperty(SignatureFile ObeSignatureFile, String[] attributes);

    /**
     * @param ObeSignatureFileList
     * @param attributes
     * @Description: 批量指定字段修改
     * @author chenxw
     */
    Integer batchUpdateProperty(List<SignatureFile> ObeSignatureFileList, String[] attributes);

    /**
     * @param ObeSignatureFileList
     * @param attributes
     * @return
     * @Description: 批量添加或跟新
     * @author chenxw
     */
    Integer batchSaveOrUpdate(List<SignatureFile> ObeSignatureFileList, String[] attributes);

    /**
     * @param tenderId
     * @return
     * @Description: 获得当前项目的流转签章文件
     * @author mazc
     */
    List<SignatureFile> getSignatureFileList(String tenderId,String reportType);

    /**
     * @param tenderId
     * @param fileList
     * @param userList
     * @Description: 添加流转签章报表
     * @author mazc
     */
    boolean saveBatchSignatureFile(List<SignatureFile> signatureFileList, List<SignatureUser> signatureUserList);

    /**
	 * @Description: 获得签名文件
	 * @author mazc
	 * @param signatureId
	 * @return 
	 */
	SignatureFile getSignatureFileById(String id);
	
	/**
	 * @Description: 根据文件名称获取待签名的文件
	 * @author mazc
	 * @param tenderId
	 * @param fileName
	 * @return 
	 */
	SignatureFile getSignatureFileByFileName(String tenderId, String fileName);
	
	 /**
	 * @Description: 批量申请流转签名
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @param userName
	 * @return 
	 */
	Integer batchApplySignatureFile(String tenderId, String userId, String userName);
	
	/**
	 * @Description: 批量释放已申请签章
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @return 
	 */
	void batchReleaseApplySignatureFile(String tenderId, String userId);
	
	/**
	 * @Description: 批量释放已申请签章
	 * @author mazc
	 * @param signatureId
	 * @return 
	 */
	void releaseApplySignatureFile(String signatureId, String userId);
	
    /**
     * @param signatureId
     * @param userId
     * @param userName
     * @return
     * @Description: 申请签章
     * @author mazc
     */
    SignatureFile applySignatureFile(String signatureId, String userId, String userName);

    /**
     * @param signatureId
     * @param signatureFileByte
     * @param userId
     * @param signatureTime
     * @return
     * @Description: 保存签章文件
     * @author mazc
     */
    boolean saveSignatureFile(String signatureId, SignatureUser signatureUser, Date signatureTime);

    /**
     * @param signatureId
     * @return
     * @Description: 删除流转签章文件
     * @author mazc
     */
    boolean deleteSignatureFile(String signatureId);

    List<SignatureFile> getSignatureFileByTenderIdAndOrderByCreateTime(String tenderId);

    /**
     * @Description: 检查报表PDF文件是否为流转文件
     * @author chenxw
     * @param tenderId
     * @param pdfFileName
     * @return
     */
    boolean checkIsReportFile(String tenderId, String pdfFileName);

    
    /**
	 * @Description: 获取当前签名文件的签名人ID
	 * @author mazc
	 * @param signatureId
	 * @return 
	 */
	String getSignatureUserId(String signatureId);
}



