package com.gx.obe.server.management.other.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.NowTimeUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.other.dao.SignatureUserMapper;
import com.gx.obe.server.management.other.entity.SignatureUser;
import com.gx.obe.server.management.other.service.SignatureUserService;

/** 
 * @Description: 
 * @author mazc 
 */
@Service
@Transactional
public class SignatureUserServiceImpl extends ServiceImpl<SignatureUserMapper, SignatureUser> implements SignatureUserService {

	@Autowired
	private SignatureUserMapper signatureUserMapper;
	
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeSignatureUserList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch (List<SignatureUser> ObeSignatureUserList){
		return signatureUserMapper.updateBatchList(ObeSignatureUserList);
	}
	
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeSignatureUserList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer insertByBatch (List<SignatureUser> ObeSignatureUserList){
		return signatureUserMapper.insertByBatch(ObeSignatureUserList);
	}

	/**
	 * @Description: 指定字段修改
	 * @author chenxw
	 * @param ObeSignatureUser
	 * @param attributes
	 */
	@Override
	public boolean updateAssignProperty(SignatureUser ObeSignatureUser, String[] attributes) {
		return signatureUserMapper.updateAssignProperty(ObeSignatureUser, attributes) > 0;
	}

	/**
	 * @Description: 批量指定字段修改
	 * @author chenxw
	 * @param ObeSignatureUserList
	 * @param attributes
	 */
	@Override
	public Integer batchUpdateProperty(List<SignatureUser> ObeSignatureUserList, String[] attributes) {
		return signatureUserMapper.batchUpdateProperty(ObeSignatureUserList, attributes);
	}

	/**
	 * @Description: 批量添加或跟新
	 * @author chenxw
	 * @param ObeSignatureUserList
	 * @param attributes
	 * @return
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public Integer batchSaveOrUpdate(List<SignatureUser> ObeSignatureUserList, String[] attributes) {
		List<SignatureUser> insertObeSignatureUserList = new ArrayList<>();
		List<SignatureUser> updateObeSignatureUserList = new ArrayList<>();
		for (SignatureUser ObeSignatureUser : ObeSignatureUserList) {
			if (StringUtils.isEmpty(ObeSignatureUser.getId())) {
				ObeSignatureUser.setId(IDUtils.getId());
				insertObeSignatureUserList.add(ObeSignatureUser);
			} else {
				updateObeSignatureUserList.add(ObeSignatureUser);
			}
		}
		int count = 0;
		if (insertObeSignatureUserList.size() > 0) {
			count += signatureUserMapper.insertByBatch(insertObeSignatureUserList);
		}
		if (updateObeSignatureUserList.size() > 0) {
			count += signatureUserMapper.batchUpdateProperty(updateObeSignatureUserList, attributes);
		}
		return count;
	}

	/**
	 * @Description: 获得当前用户需要签章的报表
	 * @author mazc
	 * @param tenderId
	 * @param userId
	 * @return
	 */
	@Override
	public List<SignatureUser> getUserSignatureFileList(String tenderId, String userId) {
		return signatureUserMapper.getUserSignatureFileList(tenderId, userId);
	}

	/** 
	 * @Description: 获得当前用户需要签章的报表
	 * @author mazc
	 * @param signatureId
	 * @param userId
	 * @return 
	 */
	@Override
	public SignatureUser getSignatureUserById(String id) {
		return signatureUserMapper.getSignatureUserById(id);
	}

	/** 
	 * @Description: 修改用户签章状态
	 * @author mazc
	 * @param id
	 * @param signatureType
	 * @param signatureTime
	 * @return 
	 */
	@Override
	public boolean updateSignatureUser(String id, String signatureType, Date signatureTime) {
		return signatureUserMapper.updateSignatureUser(id, signatureType, signatureTime) > 0;
	}

	@Override
	public List<SignatureUser> getSignatureUserBySignatureId(String signatureId) {
		QueryWrapper<SignatureUser> queryWrapper = new QueryWrapper<SignatureUser>();
		queryWrapper.lambda().eq(SignatureUser::getSignatureId, signatureId);
		return signatureUserMapper.selectList(queryWrapper);
	}
	/**
	 * @Description: 通过用户名修改用户签章状态
	 * @author guoyr
	 * @param id
	 * @param userName
	 * @param signatureType
	 * @return 
	 */
	@Override
	public boolean updateSignatureTypeByUserName(String signatureId, String userName, String signatureType) {
		Date signatureTime = NowTimeUtils.getNowDate();
		return signatureUserMapper.updateSignatureTypeByUserName(signatureId, userName, signatureType, signatureTime) > 0;
	}

}
