package com.gx.obe.server.management.project.service;
import java.util.Date;
import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.gx.obe.server.config.error.ResultBody;
import com.gx.obe.server.management.evaluation.entity.BidPrice;
import com.gx.obe.server.management.project.entity.ProjectRule;
import com.gx.obe.server.management.project.entity.TenderProject;
import com.gx.obe.server.management.supplier.entity.Supplier;
import com.gx.obe.server.management.vo.TenderPackOpeningInfo;
import com.gx.obe.server.management.vo.TenderPackPriceFactorVo;
import com.gx.obe.server.management.vo.TenderProjectVo;

 /**  
 * 
 * @author 
 * @Title: TenderProjectService
 * @Package com.gx.obe.server.management.user.service  
 * @Description:    
 * @author: XiaoMa Pro - myzhichao@163.com
 * @date:   2019-04-29   
 * @version V1.0 
 * @Copyright: 2019 www.msypro.com Inc. All rights reserved. 
 *  
 */
public interface TenderProjectService extends IService<TenderProject> {
	
	

	/**
	 * @Description: 按分页查询评标项目
	 * @author mazc
	 * @param page
	 * @param user
	 * @param useSatus
	 * @param searchKey
	 * @return 
	 */
	IPage<TenderProjectVo> getEvaluationProjectPageList(Page<TenderProjectVo> page, String userId, String userType, String evaluatonStatus, String searchKey, Date startTime, Date endTime);
	/**
	 * @Description: 分页通过id查询评标项目
	 * @author mazc
	 * @param page
	 * @param tenderId
	 * @return 
	 */
	IPage<TenderProject> findTenderPack(Page<TenderProject> page,String tenderId );
	
	
	/**
	 * @Description: 获得可唱标的包件
	 * @author mazc
	 * @param page
	 * @param tenderId
	 * @return 
	 */
	IPage<TenderProject> getSignBidTenderPackagePageList(Page<TenderProject> page,String parentId );
	
	/**
	 * @Description: 获得开标项目分页列表
	 * @author guoyr
	 * @param page
	 * @param userId
	 * @param userType
	 * @param openingStatus
	 * @param searchKey
	 * @param startTime
	 * @param endTime
	 * @return 
	 */
	IPage<TenderProjectVo> getOpeningProjectPageList(Page<TenderProjectVo> page, String userId, String userType, String openingStatus, String searchKey, Date startTime, Date endTime);
	
	/**
	 * @Description: 获取开标项目的标段分页列表
	 * @author guoyr
	 * @param page
	 * @param parentId
	 * @param userType
	 * @param openingStatus
	 * @param searchKey
	 * @param startTime
	 * @param endTime
	 * @return 
	 */
	IPage<TenderProjectVo> getOpeningTenderPackPageList(Page<TenderProjectVo> page, String parentId, String userType, String openingStatus, String searchKey, Date startTime, Date endTime);
	/**
	 * @Description: 获取评标项目的标段分页列表
	 * @author guoyr
	 * @param page
	 * @param parentId
	 * @param userType
	 * @param evaluationStatus
	 * @param searchKey
	 * @param startTime
	 * @param endTime
	 * @return 
	 */
	IPage<TenderProjectVo> getTenderPackPageList(Page<TenderProjectVo> page, String parentId, String userType, String userId, String openingStatus, String evaluationStatus, String searchKey, Date startTime, Date endTime);
	
	/**   
	 *  分页查询
	 * @Title: findByPage   
	 * @param:  page page number
	 * @param:  userId user id
	 * @param:  useSatus 用户Satus
	 * @param:  searchKey searchKey 关键字
	 * @param:  startTime startTime 开始时间
	 * @param:  endTime endTime 结束时间
	 * @return: IPage<TenderProjectVo>      
	 * @throws   
	 */  
	IPage<TenderProjectVo> getMyProjectPageList(Page<TenderProjectVo> page, String userId, String userType, String evaluationStatus, String searchKey, Date startTime, Date endTime);
	
	
	/**
	 * @Description: 按分页查询评标项目的分包
	 * @author mazc
	 * @param userId
	 * @param projectId
	 * @param useSatus
	 * @return 
	 */
	IPage<TenderProjectVo>getExpertEvaluationTenderPackPageList(Page<TenderProjectVo> page,String userId, String projectId, String useSatus);
	
	/**
	 * @Description: 按分页查询监督人监督项目
	 * @author guoyr
	 * @param page
	 * @param parentId
	 * @param evaluationStatus
	 * @param searchKey
	 * @param startTime
	 * @param endTime
	 * @return 
	 */
	IPage<TenderProjectVo> selectSuperviseProjectPage(Page<TenderProjectVo> page, String parentId, String evaluationStatus, String searchKey, Date startTime, Date endTime);
	
	
	 /**   
	 * @Title: selectSubPackagePagePage   
	 * @Description: 获得分包项目
	 * @param: @param page
	 * @param: @param parentId
	 * @param: @return      
	 * @return: IPage<TenderProjectSubVo>      
	 * @throws   
	 */  
	IPage<TenderProjectVo> selectSubPackagePage(Page<TenderProjectVo> page, String parentId);
	
	
	boolean isUniqueTenderProject(String id,String useStatus, String tenderNO, String phaseType, String parentId);

	List<String> getTenderIdList(String parentId);
	
	
	/**
	 * @Description: 验证项目是否已经进入指定的评审环节
	 * @author mazc
	 * @param tenderId
	 * @param stepType
	 * @return 
	 */
	 boolean isInEvaluation(String tenderId, String stepType);
	 
	 /**
	 * @Description:  获取标段价格指标信息
	 * @author mazc
	 * @param tenderParentId
	 * @param auditType
	 * @return 
	 */
	 List<TenderPackPriceFactorVo> selectTenderPackPriceFactor(String tenderParentId,String auditType);
	 
	 
	 /**
	 * @Description: 下载项目更新操作
	 * @author mazc
	 * @param requestBodyEntity
	 * @return 
	 */
	boolean updateDownLoadProject(TenderProject tenderProject ,ProjectRule projectRule);
	
	/**
	 * @Description: 获取开标不足三家供应商的标段
	 * @author mazc
	 * @param parentId
	 * @return 
	 */
	List<TenderProject> findUnEnoughSupplierList(String parentId);
	
	
	/**
	 * @Description: 获得专家的评审项目列表
	 * @author mazc
	 * @param userId
	 * @param searchKey
	 * @param macName
	 * @return 
	 */
	List<TenderProject> getExpertTenderProjectList(String userId, String searchKey, String macName);
	
	/**
	 * @Description: 查找和当前品目相同的相同分包
	 * @author mazc
	 * @param parentId
	 * @param purcategoryNames
	 * @param id
	 * @return 
	 */
	List<TenderProject> getPurcategoryNamesAndParentId(String parentId,String purcategoryNames,String id);
	
	
	/**
	 * @Description: 修改开标状态
	 * @author mazc
	 * @param tenderId
	 * @param parentId
	 * @param bidOpeningStatus
	 * @return 
	 */
	int updateBidOpeningStatus(String tenderId,String parentId, String bidOpeningStatus);
	
	
	/**
	 * @Description: 修改开标解密状态
	 * @author mazc
	 * @param tenderProject
	 * @param bidopeningStage
	 * @param status
	 * @return 
	 */
	int updateBidOpeningStatus(TenderProject tenderProject, String bidopeningStage, String status);

	/**
	 * @Description: 指定字段修改
	 * @author chenxw
	 * @param tenderProject
	 * @param attributes
	 * @return 
	 */
	boolean updateAssignProperty(TenderProject tenderProject, String[] attributes);
	
	
	/**
	 * @Description: 获得项目下的所有包件的开标信息
	 * @author mazc
	 * @param projectId
	 * @param bidopeningStage
	 * @return 
	 */
	List<TenderPackOpeningInfo> getTenderPackOpeningInfoList(String projectId, String bidopeningStage);
	
	/**
	 * @Description:  获得包件的开标信息
	 * @author mazc
	 * @param tenderId
	 * @param bidopeningStage
	 * @return 
	 */
	TenderPackOpeningInfo getTenderPackOpeningInfo(String tenderId, String bidopeningStage);

	
 	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeTenderProjectList 
	 */
 	Integer updateByBatch (List<TenderProject> tenderProjectList);
 	
 	/**
 	 * @Description: 批量指定字段修改
 	 * @author chenxw
 	 * @param tenderProjectList
 	 * @param attributes
 	 */
 	Integer batchUpdateProperty(List<TenderProject> tenderProjectList, String[] attributes);
	  
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeTenderProjectList 
	 */
	Integer insertByBatch (List<TenderProject> tenderProjectList);
	
	
	/**
	 * @Description: 获得分包项目
	 * @author mazc
	 * @param parentId
	 * @return 
	 */
	List<TenderProject> getSubPackageList(String parentId);
	
	
	/**
	 * @Description: 获得父级项目的开标信息
	 * @author mazc
	 * @param tenderProject
	 * @param bidopeningStage
	 * @return 
	 */
	TenderPackOpeningInfo getTenderProjectOpeningInfo(TenderProject tenderProject, String bidopeningStage);
	
	
	/**
	 * @Description: 获得包件的开标信息
	 * @author mazc
	 * @param projectId
	 * @return 
	 */
	List<TenderProject> getTenderPackBidOpeningInfoList(String projectId);
	
	
	/**
	 * @Description: 指定条件更新
	 * @author mazc
	 * @param tenderProjectList
	 * @param column
	 * @return 
	 */
	int updateByParendId(TenderProject tenderProject, String parendId);
	
	/** 
	 * @Description: 是否完成开标
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public boolean isGetLatestBidinfo(String tenderId);
	
	/** 
	 * @Description: 是否完成开标
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	public boolean isBidOpeningComplate(String tenderId);
	
	/**
	 * @Description: 评标是否结束
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	boolean isEvaluationComplate (String tenderId);
	
	TenderProject getTenderProjectByPhaseTypeTenderNumber(String tenderNo ,String phaseType,String tenderNumber);
	
	
	 /**
	 * @Description:  根据项目tenderNo和父ID，获得项目ID。
	 * @author mazc
	 * @param tenderNo
	 * @param parentId
	 * @return 
	 */
	List<String> queryTenderIdListByTenderNoAndparentId(String tenderNo,String parentId);
	
	
	/**
	 * @Description:  导入开标结果
	 * @author mazc
	 * @param tenderProject
	 * @param supplierList
	 * @param bidPriceList
	 * @param bidOpeningStage
	 * @return 
	 */
	boolean importBidOpenResult(TenderProject tenderProject, List<Supplier> supplierList, List<BidPrice> bidPriceList, String bidOpeningStage);
	
	
	/**
	 * @Description: 下载项目操作保存方法
	 * @author mazc
	 * @param tenderProject
	 * @param childTenderProject
	 * @param parentRule
	 * @param childRule
	 * @return 
	 */
	TenderProject saveDownLoadProject(TenderProject tenderProject,TenderProject childTenderProject, ProjectRule parentRule, ProjectRule childRule);

	/**
	 * @Description: 删除开标结果
	 * @author mazc
	 * @param id
	 * @return 
	 */
	int deleteBidOpeningResult(String id);
	
	
	 /**
	 * @Description:获取（查询）项目列表 
	 * @author mazc
	 * @param userId
	 * @return 
	 */
	List<TenderProject> getTenderProjectList(String userId);
	
	/**
	 * @Description: 
	 * @author mazc
	 * @param projectId
	 * @param withoutTenderId
	 * @return 
	 */
	List<Map<String, Object>> getTenderPackEvaluationInfoList(String projectId, String withoutTenderId);
	
	
	 /**
	 * @Description: 获得可生成报表的包件信息
	 * @author mazc
	 * @param projectId
	 * @param withoutTenderId
	 * @return 
	 */
	List<Map<String, Object>> getReportTenderPackInfoList(String projectId, String withoutTenderId);
	
	/**
	 * @Description: 获得当前项目下所有标段专家信息
	 * @author mazc
	 * @param projectId
	 * @param withoutTenderId
	 * @return 
	 */
	List<Map<String, Object>> getTenderPackExpertInfoList(String projectId, String withoutTenderId);
	
	
	List<TenderProject> getTenderProjectByExpert();
	
	 void restartEvaluation(String tenderId, boolean cleanData);
	 
	 /**
	 * @Description: 所有包件的项目信息来源都进行修改
	 * @author mazc
	 * @param serverId
	 * @param serverAccount
	 * @param serverPassword
	 * @param parentId
	 * @return 
	 */
	int updateServerContent(String serverId ,String serverAccount,String serverPassword,String parentId);
	
	
	/**
	 * @Description: 验证是否存在
	 * @author mazc
	 * @param tenderNo
	 * @param parentId
	 * @param phaseType
	 * @param tenderNumber
	 * @return 
	 */
	TenderProject valProjectExist(String tenderNo, String parentId, String phaseType, String tenderNumber);
	
	
	/**
	 * @Description: 修改项目的进度状态
	 * @author mazc
	 * @param tenderId
	 * @param status
	 * @return 
	 */
	int updateEvaluateStatus(String tenderId, String status);
	
	/**
	 * @Description: 验证项目是否已经完成指定阶段的开标
	 * @param tenderId
	 * @param bidopeningStage
	 * @return
	 */
	public boolean isComplateProjectOpeningByStage(String projectId, String bidopeningStage);
	
	
	/**
	 * @param id
	 * @return 
	 */
	public Integer deleteDetailByTenderId(String tenderId);
	
	
	 /**
	 * @Description: 外部删除项目
	 * @author mazc
	 * @param tenderCode	项目编号
	 * @param packCode	包件编号
	 * @param stageType 阶段类型
	 * @param tenderNumber 项目流水号
	 * @param stageId 阶段编号
	 * @return 
	 */
	ResultBody deleteProjectInfo(String tenderCode,String packCode,String stageType,String tenderNumber,String stageId);

	 /**
	  * @Description: 是否已上传评标结果
	  * @author mazc
	  * @param tenderId
	  * @return
	  */
	 boolean isUploadEvalResult(String tenderId);
	 
	 /**
	 * @param tenderId
	 * @param parentId
	 * @param archiveStatus
	 * @return
	 */
	public boolean updateEvaluationComplateStatus(String tenderId, String parentId, String archiveStatus, Date date);

     String copyProject(String tenderNo, String stageId, String tenderNonumber, String username, String password, String copyStatus);
 }

