package com.gx.obe.server.management.project.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.project.dao.ProjectRuleMapper;
import com.gx.obe.server.management.project.entity.ProjectRule;
import com.gx.obe.server.management.project.service.ProjectRuleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

  /**  
 * 
 * @author 
 * @Title: ProjectRuleService
 * @Package com.gx.obe.server.management.user.service  
 * @Description:     
 * @author: XiaoMa Pro - myzhichao@163.com
 * @date:   2019-04-30   
 * @version V1.0 
 * @Copyright: 2019 www.msypro.com Inc. All rights reserved. 
 *  
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class ProjectRuleServiceImpl extends ServiceImpl<ProjectRuleMapper, ProjectRule> implements ProjectRuleService {

	@Autowired
	private ProjectRuleMapper obeProjectRuleMapper;

	  /**
	   * @Description: 指定字段修改
	   * @author chenxw
	   * @param ObeProjectRule
	   * @param attributes
	   */
	  @Override
	  public boolean updateAssignProperty(ProjectRule ObeProjectRule, String[] attributes) {
		  return obeProjectRuleMapper.updateAssignProperty(ObeProjectRule, attributes) > 0;
	  }
	  
	  /**
	   * @Description: 批量指定字段修改
	   * @author chenxw
	   * @param ObeProjectRuleList
	   * @param attributes
	   */
	  @Override
	  public Integer batchUpdateProperty(List<ProjectRule> ObeProjectRuleList, String[] attributes) {
		  return obeProjectRuleMapper.batchUpdateProperty(ObeProjectRuleList, attributes);
	  }

	  /**
	   * @Description: 批量添加或跟新
	   * @author chenxw
	   * @param ObeProjectRuleList
	   * @param attributes
	   * @return
	   */
	  @Override
	  @Transactional(rollbackFor = Exception.class)
	  public Integer batchSaveOrUpdate(List<ProjectRule> ObeProjectRuleList, String[] attributes) {
		  List<ProjectRule> insertObeProjectRuleList = new ArrayList<>();
		  List<ProjectRule> updateObeProjectRuleList = new ArrayList<>();
		  for (ProjectRule ObeProjectRule : ObeProjectRuleList) {
			  if (StringUtils.isEmpty(ObeProjectRule.getId())) {
				  ObeProjectRule.setId(IDUtils.getId());
				  insertObeProjectRuleList.add(ObeProjectRule);
			  } else {
				  updateObeProjectRuleList.add(ObeProjectRule);
			  }
		  }
		  int count = 0;
		  if (insertObeProjectRuleList.size() > 0) {
			  count += obeProjectRuleMapper.insertByBatch(insertObeProjectRuleList);
		  }
		  if (updateObeProjectRuleList.size() > 0) {
			  count += obeProjectRuleMapper.batchUpdateProperty(updateObeProjectRuleList, attributes);
		  }
		  return count;
	  }

	@Override
	public boolean isAnonymous(String tenderId) {
		Date date =  obeProjectRuleMapper.isAnonymous(tenderId);
		return null != date && date.after(new Date());
	}

	@Override
	public ProjectRule findProjectRuleByTenderId(String tenderId) {
		QueryWrapper<ProjectRule> queryWrapper = new QueryWrapper<>();
		queryWrapper.lambda().eq(ProjectRule::getTenderId, tenderId);
		return obeProjectRuleMapper.selectOne(queryWrapper);
	}

	@Override
	public int saveOrUpdateNotNull(ProjectRule projectRule) {
		int count = 0;
		if(StringUtils.isNotEmpty(projectRule.getId())) {
			count += obeProjectRuleMapper.updateById(projectRule);
		}else {
			projectRule.setId(IDUtils.getId());
			count += obeProjectRuleMapper.insert(projectRule);
		}
 		return count;
	}

	/** 
	 * @Description: 获得项目的开标时间
	 * @author mazc
	 * @param tenderId
	 * @param bidopeningStage
	 * @return 
	 */
	@Override
	public Date getBidOpeningTime(String tenderId, String bidopeningStage) {
		return obeProjectRuleMapper.getBidOpeningTime(tenderId, bidopeningStage);
	}
	/** 
	 * @Description: 获得项目的开标时间
	 * @author mazc
	 * @param projectId
	 * @param bidopeningStage
	 * @return 
	 */
	@Override
	public List<Date> getProjectBidOpeningTime(String projectId, String bidopeningStage) {
		return obeProjectRuleMapper.getProjectBidOpeningTime(projectId, bidopeningStage);
	}

	@Override
	public ProjectRule saveOrUpdateReturn(ProjectRule projectRule) {
		if(StringUtils.isEmpty(projectRule.getId())) {
			projectRule.setId(IDUtils.getId());
			int size = obeProjectRuleMapper.insert(projectRule);
			if(size > 0) {
				return projectRule;
			}
		}else {
			int size =  obeProjectRuleMapper.updateById(projectRule);
			if(size > 0) {
				return obeProjectRuleMapper.selectById(projectRule.getId());
			}
		}
		return null;
	}

	@Override
	public int updateBidOpeningTimeOrOpeningStartTime(List<Object> tenderIdList, Date date, String dbColumnName) {
		if(null == tenderIdList || tenderIdList.size() == 0) {
			return 0;
		}
		UpdateWrapper<ProjectRule> updateWrapper = new UpdateWrapper<>();
		updateWrapper.set(dbColumnName, date);
		updateWrapper.lambda().in(ProjectRule::getTenderId, tenderIdList);
		return obeProjectRuleMapper.update(null, updateWrapper);
	}

	@Override
	public boolean updateEvalMethod(String tenderId, String evalMethod, String evalMethodName) {
		return obeProjectRuleMapper.updateEvalMethod(tenderId, evalMethod, evalMethodName) > 0;
	}

	@Override
	public boolean updateAssignPropertyByProjectId(String projectId, ProjectRule tenderProjectRuleEntity, String[] attributes) {
		obeProjectRuleMapper.updateAssignProperty(tenderProjectRuleEntity, attributes);
		return obeProjectRuleMapper.updateAssignPropertyByProjectId(projectId, tenderProjectRuleEntity, attributes) > 0;
	}
 
}
