package com.gx.obe.server.management.struct_new.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.struct_new.dao.ObeAttachmentFileMapper;
import com.gx.obe.server.management.struct_new.entity.ObeAttachmentFile;
import com.gx.obe.server.management.struct_new.service.ObeAttachmentFileService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * @author mazc
 * @Description:
 */
@Service
@Transactional
public class ObeAttachmentFileServiceImpl extends ServiceImpl<ObeAttachmentFileMapper, ObeAttachmentFile> implements ObeAttachmentFileService {

    @Autowired
    private ObeAttachmentFileMapper obeAttachmentFileMapper;

    /**
     * @param ObeAttachmentFileList
     * @Description: 批量更新
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer updateByBatch(List<ObeAttachmentFile> ObeAttachmentFileList) {
        return obeAttachmentFileMapper.updateBatchList(ObeAttachmentFileList);
    }

    /**
     * @param ObeAttachmentFileList
     * @Description: 批量插入
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer insertByBatch(List<ObeAttachmentFile> ObeAttachmentFileList) {
        return obeAttachmentFileMapper.insertByBatch(ObeAttachmentFileList);
    }

    /**
     * @param ObeAttachmentFile
     * @param attributes
     * @Description: 指定字段修改
     * @author chenxw
     */
    @Override
    public boolean updateAssignProperty(ObeAttachmentFile ObeAttachmentFile, String[] attributes) {
        return obeAttachmentFileMapper.updateAssignProperty(ObeAttachmentFile, attributes) > 0;
    }

    /**
     * @param ObeAttachmentFileList
     * @param attributes
     * @Description: 批量指定字段修改
     * @author chenxw
     */
    @Override
    public Integer batchUpdateProperty(List<ObeAttachmentFile> ObeAttachmentFileList, String[] attributes) {
        return obeAttachmentFileMapper.batchUpdateProperty(ObeAttachmentFileList, attributes);
    }

    /**
     * @param ObeAttachmentFileList
     * @param attributes
     * @return
     * @Description: 批量添加或跟新
     * @author chenxw
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer batchSaveOrUpdate(List<ObeAttachmentFile> ObeAttachmentFileList, String[] attributes) {
        List<ObeAttachmentFile> insertObeAttachmentFileList = new ArrayList<>();
        List<ObeAttachmentFile> updateObeAttachmentFileList = new ArrayList<>();
        for (ObeAttachmentFile ObeAttachmentFile : ObeAttachmentFileList) {
            if (StringUtils.isEmpty(ObeAttachmentFile.getId())) {
                ObeAttachmentFile.setId(IDUtils.getId());
                insertObeAttachmentFileList.add(ObeAttachmentFile);
            } else {
                updateObeAttachmentFileList.add(ObeAttachmentFile);
            }
        }
        int count = 0;
        if (insertObeAttachmentFileList.size() > 0) {
            count += obeAttachmentFileMapper.insertByBatch(insertObeAttachmentFileList);
        }
        if (updateObeAttachmentFileList.size() > 0) {
            count += obeAttachmentFileMapper.batchUpdateProperty(updateObeAttachmentFileList, attributes);
        }
        return count;
    }

    /**
     * @param businessId
     * @return
     * @Description: 获取附件列表
     * @author chenxw
     */
    public List<ObeAttachmentFile> getAttachmentFileList(String businessId) {
        QueryWrapper<ObeAttachmentFile> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ObeAttachmentFile::getBusinessId, businessId);
        return obeAttachmentFileMapper.selectList(queryWrapper);
    }

}
