package com.gx.obe.server.management.struct_new.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.struct_new.dao.ObeWorkExperienceMapper;
import com.gx.obe.server.management.struct_new.entity.ObeWorkExperience;
import com.gx.obe.server.management.struct_new.service.ObeWorkExperienceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * @author mazc
 * @Description:
 */
@Service
@Transactional
public class ObeWorkExperienceServiceImpl extends ServiceImpl<ObeWorkExperienceMapper, ObeWorkExperience> implements ObeWorkExperienceService {

    @Autowired
    private ObeWorkExperienceMapper obeWorkExperienceMapper;

    /**
     * @param ObeWorkExperienceList
     * @Description: 批量更新
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer updateByBatch(List<ObeWorkExperience> ObeWorkExperienceList) {
        return obeWorkExperienceMapper.updateBatchList(ObeWorkExperienceList);
    }

    /**
     * @param ObeWorkExperienceList
     * @Description: 批量插入
     * @author mazc
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer insertByBatch(List<ObeWorkExperience> ObeWorkExperienceList) {
        return obeWorkExperienceMapper.insertByBatch(ObeWorkExperienceList);
    }

    /**
     * @param ObeWorkExperience
     * @param attributes
     * @Description: 指定字段修改
     * @author chenxw
     */
    @Override
    public boolean updateAssignProperty(ObeWorkExperience ObeWorkExperience, String[] attributes) {
        return obeWorkExperienceMapper.updateAssignProperty(ObeWorkExperience, attributes) > 0;
    }

    /**
     * @param ObeWorkExperienceList
     * @param attributes
     * @Description: 批量指定字段修改
     * @author chenxw
     */
    @Override
    public Integer batchUpdateProperty(List<ObeWorkExperience> ObeWorkExperienceList, String[] attributes) {
        return obeWorkExperienceMapper.batchUpdateProperty(ObeWorkExperienceList, attributes);
    }

    /**
     * @param ObeWorkExperienceList
     * @param attributes
     * @return
     * @Description: 批量添加或跟新
     * @author chenxw
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer batchSaveOrUpdate(List<ObeWorkExperience> ObeWorkExperienceList, String[] attributes) {
        List<ObeWorkExperience> insertObeWorkExperienceList = new ArrayList<>();
        List<ObeWorkExperience> updateObeWorkExperienceList = new ArrayList<>();
        for (ObeWorkExperience ObeWorkExperience : ObeWorkExperienceList) {
            if (StringUtils.isEmpty(ObeWorkExperience.getId())) {
                ObeWorkExperience.setId(IDUtils.getId());
                insertObeWorkExperienceList.add(ObeWorkExperience);
            } else {
                updateObeWorkExperienceList.add(ObeWorkExperience);
            }
        }
        int count = 0;
        if (insertObeWorkExperienceList.size() > 0) {
            count += obeWorkExperienceMapper.insertByBatch(insertObeWorkExperienceList);
        }
        if (updateObeWorkExperienceList.size() > 0) {
            count += obeWorkExperienceMapper.batchUpdateProperty(updateObeWorkExperienceList, attributes);
        }
        return count;
    }

    /**
     * @param projectLeaderId
     * @return
     * @Description: 获取工作经历列表
     * @author chenxw
     */
    @Override
    public List<ObeWorkExperience> getWorkExperienceList(String projectLeaderId) {
        QueryWrapper<ObeWorkExperience> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ObeWorkExperience::getProjectLeaderId, projectLeaderId);
        return obeWorkExperienceMapper.selectList(queryWrapper);
    }
}
