package com.gx.obe.server.management.supplier.service.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.enumeration.BidFile;
import com.gx.obe.server.common.enumeration.CommonEnum;
import com.gx.obe.server.common.enumeration.EvaluationStepEnum;
import com.gx.obe.server.common.enumeration.SupplierEnum;
import com.gx.obe.server.common.utils.CollectionUtils;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.common.utils.StringUtils;
import com.gx.obe.server.management.evaluation.dao.BidPriceItemResultMapper;
import com.gx.obe.server.management.evaluation.dao.BidPriceResultMapper;
import com.gx.obe.server.management.evaluation.entity.BidPriceItemResult;
import com.gx.obe.server.management.evaluation.entity.BidPriceResult;
import com.gx.obe.server.management.evaluation.entity.EvaluationStep;
import com.gx.obe.server.management.supplier.dao.SupplierMapper;
import com.gx.obe.server.management.supplier.dao.SupplierOpeningResultMapper;
import com.gx.obe.server.management.supplier.entity.Supplier;
import com.gx.obe.server.management.supplier.entity.SupplierOpeningResult;
import com.gx.obe.server.management.supplier.service.SupplierService;
import com.gx.obe.server.management.vo.DecryptSupplier;
import com.gx.obe.server.management.vo.EvaluationSupplierVo;

/** 
 * @Description: 
 * @author wangxiang 
 */
@Service
public class SupplierServiceImpl extends ServiceImpl<SupplierMapper, Supplier> implements SupplierService {

	@Autowired
	private SupplierMapper supplierMapper;
	@Autowired
	private BidPriceResultMapper bidPriceResultMapper;
	@Autowired
	private BidPriceItemResultMapper bidPriceItemResultMapper;
	@Autowired
	private SupplierOpeningResultMapper supplierOpeningResultMapper;

	@Override
	public List<Supplier> getSupplierList(String tenderId,String useStatus) {
		return supplierMapper.getSupplierList(tenderId,useStatus);
	}

	@Override
	public List<Supplier> getOpenBidSuccessSupplier(String tenderId, String bidFileType) {
		List<Supplier> supplierList = supplierMapper.getOpenBidSuccessSupplier(tenderId, CommonEnum.REAL_STATUS, SupplierEnum.OPENBID_SUCCESS, SupplierEnum.REVOKE_NO);
		if (BidFile.PRIVATE_BID_FILE.equals(bidFileType)) {
			initPrivateBidSupplierList(supplierList, null);
		}
		return supplierList;
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean removeSupplier(String tenderId,String supplierId) {
		boolean remove = false;
		boolean removeSupplier = supplierMapper.removeSupplier(supplierId) > 0;
		if(removeSupplier) {
			//删除报价结果表 报价明细结果表 开标结果表
			QueryWrapper<SupplierOpeningResult> supplierOpeningResultQueryWrapper = new QueryWrapper<>();
			supplierOpeningResultQueryWrapper.lambda().eq(SupplierOpeningResult::getTenderId, tenderId);
			
			QueryWrapper<BidPriceResult> queryWrapper = new QueryWrapper<>();
	        queryWrapper.lambda().eq(BidPriceResult::getTenderId, tenderId);
	        
	        QueryWrapper<BidPriceItemResult> queryWrapper_1 = new QueryWrapper<>();
	        queryWrapper_1.lambda().eq(BidPriceItemResult::getTenderId, tenderId);
	        
	        if(null != supplierId) {
	        	supplierOpeningResultQueryWrapper.lambda().eq(SupplierOpeningResult::getSupplierId, supplierId);
	        	queryWrapper.lambda().eq(BidPriceResult::getSupplierId, supplierId);
	        	queryWrapper_1.lambda().eq(BidPriceItemResult::getSupplierId, supplierId);
	        }
	        supplierOpeningResultMapper.delete(supplierOpeningResultQueryWrapper) ;
	        bidPriceResultMapper.delete(queryWrapper) ;
	        bidPriceItemResultMapper.delete(queryWrapper_1) ;
	        remove = true;
		}
		return remove;
	}

	@Override
	public List<Supplier> getSupplierOpenBidList(String tenderId) {
		return supplierMapper.getSupplierOpenBidList(tenderId);
	}

	/** 
	 * @Description: 批量添加或跟新
	 * @author mazc
	 * @param supplierList
	 * @return 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
    public int batchSaveOrUpdate(List<Supplier> supplierList, String[] attributes) {
        List<Supplier> insertSupplierList = new ArrayList<Supplier>();
        List<Supplier> updateSupplierList = new ArrayList<Supplier>();
        for (Supplier supplier : supplierList) {
            if (StringUtils.isEmpty(supplier.getId())) {
                supplier.setId(IDUtils.getId());
                insertSupplierList.add(supplier);
            } else {
                updateSupplierList.add(supplier);
            }
        }
        int count = 0;
        if (insertSupplierList.size() > 0) {
            count = count + supplierMapper.insertByBatch(insertSupplierList);
        }
        if (updateSupplierList.size() > 0) {
            count = count + supplierMapper.batchUpdateProperty(updateSupplierList, attributes);
        }
        return count;
    }

	
	@Override
	@Transactional(rollbackFor = Exception.class)
	public int insertByBatch(List<Supplier> supplierList) {
		return supplierMapper.insertByBatch(supplierList);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch(List<Supplier> ObeSupplierList) {
		return supplierMapper.updateObeSupplierBatchList(ObeSupplierList);
	}

	/** 
	 * @Description: 获取开标供应商的数量
	 * @author mazc
	 * @param tenderId
	 * @return 
	 */
	@Override
	public Integer findSupplierOpeningCount(String tenderId) {
		return supplierMapper.findSupplierOpeningCount(tenderId);
	}

	/** 
	 * @Description: 批量指定字段修改
	 * @author chenxw
	 * @param supplierList
	 * @param attributes
	 * @return 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
    public Integer batchUpdateProperty(List<Supplier> supplierList, String[] attributes) {
        return supplierMapper.batchUpdateProperty(supplierList, attributes);
    }

	/**
	 * @Description: 按照签到顺序排序
	 * @author wangxiang
	 * @param tenderProjectId
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean sortSupplierBySignTime(String tenderProjectId, boolean order) {
		QueryWrapper<Supplier> queryWrapper = new QueryWrapper<>();
		queryWrapper.lambda().eq(Supplier::getTenderId, tenderProjectId);
		if(order) {
			queryWrapper.orderByDesc("SIGN_TIME");
		}else {
			queryWrapper.orderByAsc("SIGN_TIME");
		}
		queryWrapper.orderByAsc("SORT_NO");
		
		List<Supplier> supplierList = supplierMapper.selectList(queryWrapper);
		if(null != supplierList && supplierList.size() > 0) {
			int sortNo = 1;
			int lastSort = supplierList.size();
			for(Supplier supplier : supplierList){
				if(null != supplier.getSignTime()){
					supplier.setSortNo(sortNo++);
				}else {
					supplier.setSortNo(lastSort--);
				}
			}
			
			return supplierMapper.sortSupplierBySignTime(supplierList) > 0;
		}else {
			return false;
		}
		
	}

	/**
	 * @Description: 获得所有未投标的投标人
	 * @author wangxiang
	 * @param tenderId
	 * @return 
	 */
	@Override
	public List<Supplier> getAllUnTenderSupplierList(String tenderId) {
		return supplierMapper.getAllUnTenderSupplierList(tenderId);
	}

	/** 
	 * @Description: 指定字段修改
	 * @author chenxw
	 * @param supplier
	 * @param attributes
	 * @return 
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
    public boolean updateAssignProperty(Supplier supplier, String[] attributes) {
        return supplierMapper.updateAssignProperty(supplier, attributes) > 0;
    }

	/**
	 * @Description: 验证供应商属性是否唯一
	 * @author wangxiang
	 * @param tenderId 项目 
	 * @param supplierId 主键
	 * @param column 数据库字段
	 * @param columnValue 字段值
	 * @return 
	 */
	@Override
	public boolean isUniqueSupplier(String tenderId, String supplierId, String column, String columnValue) {
		return supplierMapper.isUniqueSupplier(tenderId,supplierId,column,columnValue) == 0;
	}
	
	/**
	 * @Description: 验证投标人名称是否唯一
	 * @author wangxiang
	 * @param tenderId
	 * @param supplierId
	 * @param supplierName
	 * @return 
	 */
	@Override
	public Integer isUniqueSupplierByName(String tenderId, String supplierId, String supplierName) {
		return supplierMapper.isUniqueSupplierByName(tenderId,supplierId,supplierName);
	}

	/**
	 * @Description: 获得指定评标步骤下的供应商列表
	 * @author wangxiang
	 * @param evaluationSupplierVo
	 * @return
	 */
	@Override
	public List<Supplier> getEvaluationStepSupplierList(EvaluationSupplierVo evaluationSupplierVo) {
		String tenderId = evaluationSupplierVo.getTenderId();
		EvaluationStep evaluationStep = evaluationSupplierVo.getEvaluationStep();
		
		List<Supplier> supplierList = null;
		if (evaluationStep.getSortNo() != null) {
			if(evaluationStep.getSortNo() == 1  || evaluationStep.getStepType().equals(EvaluationStepEnum.SIGIN)){
				supplierList = supplierMapper.getOpenBidSuccessSupplier(tenderId,CommonEnum.REAL_STATUS,SupplierEnum.OPENBID_SUCCESS,SupplierEnum.REVOKE_NO);
			}else{
				supplierList = supplierMapper.getEvaluationStepSupplierList(tenderId,SupplierEnum.REVOKE_NO, SupplierEnum.OPENBID_SUCCESS,CommonEnum.COMPLETE, EvaluationStepEnum.UNQUALIFIED, evaluationStep.getSortNo());
				if(null == supplierList){
					supplierList = new ArrayList<Supplier>();
				}
			}
		}
		if (evaluationStep.getEvaluationParamByKey(EvaluationStepEnum.PARAM_SEALED_BID, boolean.class)) {
			initPrivateBidSupplierList(supplierList, evaluationStep);
		}
		return supplierList;
	}
	
	/**
	 * @Description: 初始化暗标供应商列表
	 * @author wangxiang
	 * @param supplierList
	 * @param evaluationStep 
	 */
	private void initPrivateBidSupplierList(List<Supplier> supplierList, EvaluationStep evaluationStep) {
		if (CollectionUtils.isNull(supplierList)) {
			return;
		}
		for (Supplier supplier : supplierList) {
			if (StringUtils.isEmpty(supplier.getSealedBidCode())) {
				supplier.setSealedBidCode(supplier.getId().substring(0, 6));
			}
			supplier.setSupplierName(supplier.getSealedBidCode());
		}
		boolean orderbySealedBidCode = true;
		if (null != evaluationStep) {
			orderbySealedBidCode = evaluationStep.getEvaluationParamByKey(EvaluationStepEnum.PARAM_ORDERBY_SEALED_BID_CODE, boolean.class);
		}
		if (orderbySealedBidCode) {
			Collections.sort(supplierList, new SupplierComparator());
		}
	}
	
	/**
	 * @Description: 获得投标人的开标结果和评标结果
	 * @author wangxiang
	 * @param tenderId
	 * @return
	 */
	@Override
	public List<Supplier> getSupplierOpenbidAndEvaluateResultList(String tenderId) {
		return supplierMapper.getSupplierOpenbidAndEvaluateResultList(tenderId,CommonEnum.REAL_STATUS);
	}
	
	/**
	 * @Description: 获得投标人的最大序号
	 * @author wangxiang
	 * @param tenderId
	 * @return
	 */
	@Override
	public int getMaxSupplierSortNo(String tenderId) {
	    Integer maxSortNo =  supplierMapper.getMaxSupplierSortNo(tenderId);
	    return null != maxSortNo ? maxSortNo.intValue() : 0;
	}
	
	/**
	 * @Description: 获得指定步骤评审不通过的投标人
	 * @author wangxiang
	 * @param tenderId
	 * @param stepId 指定的评标步骤
	 * @return
	 */
	public List<Supplier> getDisAccessmentSupplier(String tenderId, String stepId){
		return supplierMapper.getDisAccessmentSupplier(tenderId,EvaluationStepEnum.UNQUALIFIED,stepId,CommonEnum.REAL_STATUS);
	}
	
	/**
	 * @Description: 
	 * @author guoyr
	 */
	class SupplierComparator implements Comparator<Supplier>{

		public int compare(Supplier supplier1, Supplier supplier2) {
			if(null == supplier1.getSealedBidCode() || null == supplier2.getSealedBidCode()){
				return 0;
			}
			int comp = supplier1.getSealedBidCode().compareToIgnoreCase(supplier2.getSealedBidCode());
			if (comp < 0) {
				return -1;
			}else if(comp > 0){
				return 1;
			}
			return 0;
		}
	}

	/**
	 * @Description: 根据项目Id，获得项目下所有分包的投标人集合(去重复)
	 * @author wangxiang
	 * @param tenderParentId 项目Id
	 * @return List<Supplier>
	 */
	@Override
	public List<Supplier> getSupplierListByTenderProject(String tenderParentId) {
		return supplierMapper.getSupplierListByTenderProject(tenderParentId,CommonEnum.REAL_STATUS);
	}

	/**
	 * @Description: 模糊查询投标人名称或编码，获得项目下的投标人列表。
	 * @author wangxiang
	 * @param tenderId 项目ID
	 * @param content 查询条件(投标人名称和编码)
	 * @return List<Supplier>
	 */
	@Override
	public List<Supplier> getSupplierListByName(String tenderId, String content) {
		return supplierMapper.getSupplierListByName(tenderId,CommonEnum.REAL_STATUS,content);
	}

	/**
	 * @Description: 根据父项目id查询所有包件下的投标人信息
	 * @author wangxiang
	 * @param parentId
	 * @return 
	 */
	@Override
	public List<Map<String, Object>> getparentSupplierByParentTenderId(String parentId) {
		return supplierMapper.getparentSupplierByParentTenderId(parentId);
	}

	/**
	 * @Description: 获得报名供应商的个数
	 * @author wangxiang
	 * @param tenderId
	 * @return 
	 */
	@Override
	public Integer getSupplierCount(String tenderId) {
		return supplierMapper.getSupplierCount(tenderId);
	}

	/**
	 * @Description: 获得未废标且已签到的供应商家数
	 * @author wangxiang
	 * @param tenderId
	 * @return 
	 */
	@Override
	public Integer getSupplierSignCount(String tenderId){
		return supplierMapper.getSupplierSignCount(tenderId,SupplierEnum.REVOKE_YES);
	}

	/**
	 * @Description: 获得推荐的供应商列表
	 * @author wangxiang
	 * @param tenderId
	 * @param stepIndex
	 * @return 
	 */
	@Override
	public List<Supplier> getRecommendSupplierList(String tenderId, int stepIndex) {
		return supplierMapper.getRecommendSupplierList(tenderId,SupplierEnum.REVOKE_NO, SupplierEnum.OPENBID_SUCCESS,CommonEnum.COMPLETE, EvaluationStepEnum.UNQUALIFIED, stepIndex);
	}

	/**
	 * @Description: 获得按项目开标的供应商
	 * @author wangxiang
	 * @param projectId
	 * @return 
	 */
	@Override
	public List<DecryptSupplier> getDecryptSupplierList(String projectId, String tenderId, boolean onlyTenderBid) {
		List<DecryptSupplier> decryptSupplierList = null;
		List<Supplier> supplierList = supplierMapper.getDecryptSupplierList(projectId,tenderId,onlyTenderBid);
		if(null != supplierList && supplierList.size() > 0){
			decryptSupplierList  = new ArrayList<DecryptSupplier>();
			Map<String, DecryptSupplier> decryptSupplierMap = new LinkedHashMap<String, DecryptSupplier>();// 据输入的顺序输出
			   
			for(Supplier supplier : supplierList){
				if(onlyTenderBid && null == supplier.getTenderTime()){
					continue;
				}
				DecryptSupplier decryptSupplier = null;
				if(decryptSupplierMap.containsKey(supplier.getSupplierName())){
					decryptSupplier = decryptSupplierMap.get(supplier.getSupplierName());
				}else {
					decryptSupplier = new DecryptSupplier(supplier);
					if(null != tenderId){
						decryptSupplier.setSupplierId(supplier.getId());
					}
					decryptSupplierMap.put(supplier.getSupplierName(), decryptSupplier);
				}
				decryptSupplier.addSupplier(supplier);
			}
			
			for(Map.Entry<String, DecryptSupplier> e : decryptSupplierMap.entrySet()){
				decryptSupplierList.add(e.getValue());
			}
		}
		
		return decryptSupplierList;
	}

	/**
	 * @Description: 通过项目id查找项目下所有包件中资审为通过供应商数量
	 * @author wangxiang
	 * @param tenderParentId
	 * @param accessment [01：通过；02：不通过]
	 * @return 
	 */
	@Override
	public List<Supplier> getComplianceFailSupplierCount(String tenderParentId, String accessment) {
		return supplierMapper.getComplianceFailSupplierCount(tenderParentId,accessment);
	}

	/**
	 * @Description: 获得整个项目下开标成功的投标人列表
	 * @author wangxiang
	 * @param tenderParentId
	 * @return
	 */
	@Override
	public List<Supplier> getOpenBidSuccessByParentId(String tenderParentId) {
		return supplierMapper.getOpenBidSuccessByParentId(tenderParentId,CommonEnum.REAL_STATUS,SupplierEnum.OPENBID_SUCCESS, SupplierEnum.REVOKE_NO);
	}

	/**
	 * @Description: 获得供应商开标信息
	 * @author wangxaing
	 * @param tenderId
	 * @return 
	 */
	@Override
	public List<Map<String, Object>> getSupplierBidOpeningInfoList(String tenderId) {
		return supplierMapper.getSupplierBidOpeningInfoList(tenderId);
	}

	/**
	 * @Description: 根据包件id查询该包件下，供应商投标人数
	 * @author wangxiang
	 * @param tenderId
	 * @return 
	 */
	@Override
	public Integer getBidSupplierCount(String tenderId) {
		return supplierMapper.getBidSupplierCount(tenderId);
	}

	/**
	 * @Description: 根据包件id查询该包件下，供应商商务技术解密人数
	 * @author wangxiang
	 * @param tenderId
	 * @param priceBidStatus
	 * @return 
	 */
	@Override
	public Integer getSupplierBusinessDecryptCount(String tenderId, boolean priceBidStatus) {
		return supplierMapper.getSupplierBusinessDecryptCount(tenderId,SupplierEnum.OPENBID_SUCCESS,priceBidStatus);
	}

	@Override
	public List<Map<String, Object>> queryToMap(String tenderId,boolean hasParent) {
		return supplierMapper.queryToMap(tenderId,hasParent);
	}

	@Override
	public boolean deleteAllSupplierByTenderId(String tenderId) {
		QueryWrapper<Supplier> queryWrapper = new QueryWrapper<>();
		queryWrapper.lambda().eq(Supplier::getTenderId, tenderId);

		supplierOpeningResultMapper.deleteByTenderId(tenderId);
		
        bidPriceResultMapper.deleteByTenderId(tenderId);
        
		return supplierMapper.delete(queryWrapper)>0;
	}

	@Override
	public List<Supplier> getPrivceRoundSupplierList(String roundId) {
		return supplierMapper.getPrivceRoundSupplierList(roundId);
	}

}
