package com.gx.obe.server.management.user.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gx.obe.server.common.utils.IDUtils;
import com.gx.obe.server.management.user.dao.CaBindingMapper;
import com.gx.obe.server.management.user.entity.CaBinding;
import com.gx.obe.server.management.user.service.CaBindingService;

/** 
 * @Description: 
 * @author mazc 
 */
@Service
@Transactional
public class CaBindingServiceImpl extends ServiceImpl<CaBindingMapper, CaBinding> implements CaBindingService {

	@Autowired
	private CaBindingMapper caBindingMapper;
	
	/**
	 * @Description: 批量更新
	 * @author mazc
	 * @param ObeCaBindingList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer updateByBatch (List<CaBinding> ObeCaBindingList){
		return caBindingMapper.updateBatchList(ObeCaBindingList);
	}
	
	/**
	 * @Description: 批量插入
	 * @author mazc
	 * @param ObeCaBindingList 
	 */
	 @Override
	 @Transactional(rollbackFor = Exception.class)
	public Integer insertByBatch (List<CaBinding> ObeCaBindingList){
		return caBindingMapper.insertByBatch(ObeCaBindingList);
	}

	 
	@Override
	public boolean saveOrUpdateEntity(CaBinding caBinding) {
		if(null != caBinding && caBinding.getId().length() > 0) {
			return	caBindingMapper.updateById(caBinding) > 0;
 		}else {
 			caBinding.setId(IDUtils.getId());
 			return	caBindingMapper.insert(caBinding) > 0;
 		}
 	}

	/** 
	 * @Description: 通过用户id 获取ca信息
	 * @author mazc
	 * @param userId
	 * @return 
	 */
	@Override
	public List<CaBinding> getCaBindingByUserIdOrderBy(String userId) {
		QueryWrapper<CaBinding> queryWrapper = new QueryWrapper<CaBinding>();
		queryWrapper.lambda().eq(CaBinding::getUserId, userId).orderByDesc(CaBinding::getValidTime);
		return caBindingMapper.selectList(queryWrapper);
	}

	@Override
	public int getCaBindingByCertIdAndUserIdSize(String certId, String userId) {
		QueryWrapper<CaBinding> queryWrapper = new QueryWrapper<CaBinding>();
		queryWrapper.select(CaBinding.CERT_ID).lambda().eq(CaBinding::getCertId, certId).eq(CaBinding::getUserId, userId);
		return caBindingMapper.selectList(queryWrapper).size();
	}

	@Override
	public CaBinding getCaBindingByCertIdAndUserId(String certId, String userId) {
		QueryWrapper<CaBinding> queryWrapper = new QueryWrapper<CaBinding>();
		queryWrapper.lambda().eq(CaBinding::getCertId, certId).eq(CaBinding::getUserId, userId);
		return caBindingMapper.selectOne(queryWrapper);
	}
	

}
